=== modified file 'bzrlib/_dirstate_helpers_py.py'
--- bzrlib/_dirstate_helpers_py.py	2007-10-09 03:35:33 +0000
+++ bzrlib/_dirstate_helpers_py.py	2008-04-24 07:22:53 +0000
@@ -200,7 +200,9 @@
     fields = text.split('\0')
     # Remove the last blank entry
     trailing = fields.pop()
-    assert trailing == ''
+    if trailing != '':
+        raise AssertionError("dirtstate line %r has trailing garbage: %r" 
+            % (trailing,))
     # consider turning fields into a tuple.
 
     # skip the first field which is the trailing null from the header.
@@ -217,11 +219,12 @@
     expected_field_count = entry_size * state._num_entries
     field_count = len(fields)
     # this checks our adjustment, and also catches file too short.
-    assert field_count - cur == expected_field_count, \
-        'field count incorrect %s != %s, entry_size=%s, '\
-        'num_entries=%s fields=%r' % (
+    if field_count - cur != expected_field_count:
+        raise AssertionError(
+            'field count incorrect %s != %s, entry_size=%s, '\
+            'num_entries=%s fields=%r' % (
             field_count - cur, expected_field_count, entry_size,
-            state._num_entries, fields)
+            state._num_entries, fields))
 
     if num_present_parents == 1:
         # Bind external functions to local names
@@ -269,7 +272,8 @@
                      ),
                      ])
             trailing = next()
-            assert trailing == '\n'
+            if trailing != '\n':
+                raise ValueError("trailing garbage in dirstate: %r" % trailing)
             # append the entry to the current block
             append_entry(entry)
         state._split_root_dirblock_into_contents()

=== modified file 'bzrlib/_patiencediff_py.py'
--- bzrlib/_patiencediff_py.py	2007-09-04 09:10:35 +0000
+++ bzrlib/_patiencediff_py.py	2008-04-24 07:22:53 +0000
@@ -197,8 +197,10 @@
     next_a = -1
     next_b = -1
     for a,b,match_len in answer:
-        assert a >= next_a, 'Non increasing matches for a'
-        assert b >= next_b, 'Not increasing matches for b'
+        if a < next_a:
+            raise ValueError('Non increasing matches for a')
+        if b < next_b:
+            raise ValueError('Not increasing matches for b')
         next_a = a + match_len
         next_b = b + match_len
 

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2008-04-23 01:46:46 +0000
+++ bzrlib/annotate.py	2008-04-24 07:22:53 +0000
@@ -342,6 +342,5 @@
         last_right_idx = right_idx + match_len
         last_left_idx = left_idx + match_len
         # If left and right agree on a range, just push that into the output
-        assert len(lines) == left_idx
         lines_extend(annotated_lines[left_idx:left_idx + match_len])
     return lines

=== modified file 'bzrlib/atomicfile.py'
--- bzrlib/atomicfile.py	2006-10-16 01:25:46 +0000
+++ bzrlib/atomicfile.py	2008-04-24 07:22:53 +0000
@@ -51,8 +51,6 @@
         global _hostname
 
         self._fd = None
-        assert mode in ('wb', 'wt'), \
-            "invalid AtomicFile mode %r" % mode
 
         if _hostname is None:
             _hostname = socket.gethostname()
@@ -64,6 +62,8 @@
         flags = os.O_EXCL | os.O_CREAT | os.O_WRONLY
         if mode == 'wb':
             flags |= osutils.O_BINARY
+        elif mode != 'wt':
+            raise ValueError("invalid AtomicFile mode %r" % mode)
 
         if new_mode is not None:
             local_mode = new_mode

=== modified file 'bzrlib/benchmarks/tree_creator/kernel_like.py'
--- bzrlib/benchmarks/tree_creator/kernel_like.py	2007-09-13 22:41:38 +0000
+++ bzrlib/benchmarks/tree_creator/kernel_like.py	2008-04-24 07:22:53 +0000
@@ -195,7 +195,6 @@
             returns only an in-memory Inventory, so it should always be None.
         :return: An Inventory object.
         """
-        assert root is None, "Cannot create a memory inventory in a on disk."
         cache_dir = self._get_cache_dir()
         if cache_dir is None:
             return self._create_and_return()

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2008-04-11 04:51:44 +0000
+++ bzrlib/branch.py	2008-04-24 07:22:53 +0000
@@ -317,7 +317,6 @@
         The delta is relative to its mainline predecessor, or the
         empty tree for revision 1.
         """
-        assert isinstance(revno, int)
         rh = self.revision_history()
         if not (1 <= revno <= len(rh)):
             raise errors.InvalidRevisionNumber(revno)
@@ -451,7 +450,6 @@
         if stop_revision is None:
             stop_revision = other_len
         else:
-            assert isinstance(stop_revision, int)
             if stop_revision > other_len:
                 raise errors.NoSuchRevision(self, stop_revision)
         return other_history[self_len:stop_revision]
@@ -939,7 +937,6 @@
 
     @classmethod
     def unregister_format(klass, format):
-        assert klass._formats[format.get_format_string()] is format
         del klass._formats[format.get_format_string()]
 
     def __str__(self):
@@ -1149,7 +1146,9 @@
         """
         if not _found:
             format = BranchFormat.find_format(a_bzrdir)
-            assert format.__class__ == self.__class__
+            if format.__class__ != self.__class__:
+                raise AssertionError("wrong format %r found for %r" %
+                    (format, self))
         try:
             transport = a_bzrdir.get_branch_transport(None)
             control_files = lockable_files.LockableFiles(transport, 'lock',
@@ -1197,7 +1196,9 @@
         """
         if not _found:
             format = BranchFormat.find_format(a_bzrdir)
-            assert format.__class__ == self.__class__
+            if format.__class__ != self.__class__:
+                raise AssertionError("wrong format %r found for %r" %
+                    (format, self))
         transport = a_bzrdir.get_branch_transport(None)
         control_files = lockable_files.LockableFiles(transport, 'lock',
                                                      lockdir.LockDir)
@@ -1277,7 +1278,9 @@
         """
         if not _found:
             format = BranchFormat.find_format(a_bzrdir)
-            assert format.__class__ == self.__class__
+            if format.__class__ != self.__class__:
+                raise AssertionError("wrong format %r found for %r" %
+                    (format, self))
         if location is None:
             location = self.get_reference(a_bzrdir)
         real_bzrdir = bzrdir.BzrDir.open(
@@ -1444,8 +1447,12 @@
         """
         revision_id = _mod_revision.ensure_null(revision_id)
         old_revno, old_revid = self.last_revision_info()
+        # this old format stores the full history, but this api doesn't
+        # provide it, so we must generate, and might as well check it's
+        # correct
         history = self._lefthand_history(revision_id)
-        assert len(history) == revno, '%d != %d' % (len(history), revno)
+        if len(history) != revno:
+            raise AssertionError('%d != %d' % (len(history), revno))
         self.set_revision_history(history)
         self._run_post_change_branch_tip_hooks(old_revno, old_revid)
 
@@ -1525,7 +1532,8 @@
                 elif heads == set([stop_revision, last_rev]):
                     # These branches have diverged
                     raise errors.DivergedBranches(self, other)
-                assert heads == set([stop_revision])
+                elif heads != set([stop_revision]):
+                    raise AssertionError("invalid heads: %r" % heads)
             if other_last_revision == stop_revision:
                 self.set_last_revision_info(other_last_revno,
                                             other_last_revision)
@@ -1677,8 +1685,6 @@
 
     def get_parent(self):
         """See Branch.get_parent."""
-
-        assert self.base[-1] == '/'
         parent = self._get_parent_location()
         if parent is None:
             return parent
@@ -1720,7 +1726,6 @@
         if url is None:
             self.control_files._transport.delete('parent')
         else:
-            assert isinstance(url, str)
             self.control_files.put_bytes('parent', url + '\n')
 
 
@@ -1896,7 +1901,7 @@
         Intended to be called by set_last_revision_info and
         _write_revision_history.
         """
-        assert revision_id is not None, "Use NULL_REVISION, not None"
+        revision_id = _mod_revision.ensure_null(revision_id)
         out_string = '%d %s\n' % (revno, revision_id)
         self.control_files.put_bytes('last-revision', out_string)
 
@@ -1945,7 +1950,6 @@
             iterator = repo.iter_reverse_revision_history(start_revision)
             #skip the last revision in the list
             next_revision = iterator.next()
-            assert next_revision == start_revision
         for revision_id in iterator:
             self._partial_revision_history_cache.append(revision_id)
             if (stop_index is not None and
@@ -2081,7 +2085,6 @@
             raise errors.NoSuchRevision(self, revno)
 
         if history is not None:
-            assert len(history) == last_revno, 'revno/history mismatch'
             return history[revno - 1]
 
         index = last_revno - revno

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2008-04-12 06:46:35 +0000
+++ bzrlib/builtins.py	2008-04-24 07:22:53 +0000
@@ -1298,7 +1298,6 @@
             last_revision = wt.last_revision()
 
         revision_ids = b.repository.get_ancestry(last_revision)
-        assert revision_ids[0] is None
         revision_ids.pop(0)
         for revision_id in revision_ids:
             self.outf.write(revision_id + '\n')
@@ -1723,8 +1722,6 @@
             message=None,
             limit=None):
         from bzrlib.log import show_log
-        assert message is None or isinstance(message, basestring), \
-            "invalid message argument %r" % message
         direction = (forward and 'forward') or 'reverse'
         
         # log everything
@@ -2972,7 +2969,6 @@
                                 possible_transports, pb):
         """Produce a merger from a location, assuming it refers to a branch."""
         from bzrlib.tag import _merge_tags_if_possible
-        assert revision is None or len(revision) < 3
         # find the branch locations
         other_loc, user_location = self._select_branch_location(tree, location,
             revision, -1)

=== modified file 'bzrlib/bundle/bundle_data.py'
--- bzrlib/bundle/bundle_data.py	2007-09-25 08:14:12 +0000
+++ bzrlib/bundle/bundle_data.py	2008-04-24 07:22:53 +0000
@@ -78,7 +78,8 @@
             for property in self.properties:
                 key_end = property.find(': ')
                 if key_end == -1:
-                    assert property.endswith(':')
+                    if not property.endswith(':'):
+                        raise ValueError(property)
                     key = str(property[:-1])
                     value = ''
                 else:
@@ -196,7 +197,8 @@
     def revision_tree(self, repository, revision_id, base=None):
         revision = self.get_revision(revision_id)
         base = self.get_base(revision)
-        assert base != revision_id
+        if base == revision_id:
+            raise AssertionError()
         if not self._validated_revisions_against_repo:
             self._validate_references_from_repository(repository)
         revision_info = self.get_revision_info(revision_id)
@@ -286,15 +288,13 @@
         """At this point we should have generated the BundleTree,
         so build up an inventory, and make sure the hashes match.
         """
-
-        assert inv is not None
-
         # Now we should have a complete inventory entry.
         s = serializer_v5.write_inventory_to_string(inv)
         sha1 = sha_string(s)
         # Target revision is the last entry in the real_revisions list
         rev = self.get_revision(revision_id)
-        assert rev.revision_id == revision_id
+        if rev.revision_id != revision_id:
+            raise AssertionError()
         if sha1 != rev.inventory_sha1:
             open(',,bogus-inv', 'wb').write(s)
             warning('Inventory sha hash mismatch for revision %s. %s'
@@ -308,8 +308,10 @@
         
         rev = self.get_revision(revision_id)
         rev_info = self.get_revision_info(revision_id)
-        assert rev.revision_id == rev_info.revision_id
-        assert rev.revision_id == revision_id
+        if not (rev.revision_id == rev_info.revision_id):
+            raise AssertionError()
+        if not (rev.revision_id == revision_id):
+            raise AssertionError()
         sha1 = self._testament_sha1(rev, inventory)
         if sha1 != rev_info.sha1:
             raise TestamentMismatch(rev.revision_id, rev_info.sha1, sha1)
@@ -347,7 +349,6 @@
                 if name == 'last-changed':
                     last_changed = value
                 elif name == 'executable':
-                    assert value in ('yes', 'no'), value
                     val = (value == 'yes')
                     bundle_tree.note_executable(new_path, val)
                 elif name == 'target':
@@ -357,11 +358,12 @@
             return last_changed, encoding
 
         def do_patch(path, lines, encoding):
-            if encoding is not None:
-                assert encoding == 'base64'
+            if encoding == 'base64':
                 patch = base64.decodestring(''.join(lines))
-            else:
+            elif encoding is None:
                 patch =  ''.join(lines)
+            else:
+                raise ValueError(encoding)
             bundle_tree.note_patch(path, patch)
 
         def renamed(kind, extra, lines):
@@ -495,8 +497,10 @@
 
     def note_rename(self, old_path, new_path):
         """A file/directory has been renamed from old_path => new_path"""
-        assert new_path not in self._renamed
-        assert old_path not in self._renamed_r
+        if new_path in self._renamed:
+            raise AssertionError(new_path)
+        if old_path in self._renamed_r:
+            raise AssertionError(old_path)
         self._renamed[new_path] = old_path
         self._renamed_r[old_path] = new_path
 
@@ -532,7 +536,8 @@
 
     def old_path(self, new_path):
         """Get the old_path (path in the base_tree) for the file at new_path"""
-        assert new_path[:1] not in ('\\', '/')
+        if new_path[:1] in ('\\', '/'):
+            raise ValueError(new_path)
         old_path = self._renamed.get(new_path)
         if old_path is not None:
             return old_path
@@ -558,7 +563,8 @@
         """Get the new_path (path in the target_tree) for the file at old_path
         in the base tree.
         """
-        assert old_path[:1] not in ('\\', '/')
+        if old_path[:1] in ('\\', '/'):
+            raise ValueError(old_path)
         new_path = self._renamed_r.get(old_path)
         if new_path is not None:
             return new_path
@@ -637,11 +643,13 @@
             if (patch_original is None and 
                 self.get_kind(file_id) == 'directory'):
                 return StringIO()
-            assert patch_original is not None, "None: %s" % file_id
+            if patch_original is None:
+                raise AssertionError("None: %s" % file_id)
             return patch_original
 
-        assert not file_patch.startswith('\\'), \
-            'Malformed patch for %s, %r' % (file_id, file_patch)
+        if file_patch.startswith('\\'):
+            raise ValueError(
+                'Malformed patch for %s, %r' % (file_id, file_patch))
         return patched_file(file_patch, patch_original)
 
     def get_symlink_target(self, file_id):
@@ -694,8 +702,6 @@
         This need to be called before ever accessing self.inventory
         """
         from os.path import dirname, basename
-
-        assert self.base_tree is not None
         base_inv = self.base_tree.inventory
         inv = Inventory(None, self.revision_id)
 

=== modified file 'bzrlib/bundle/serializer/v08.py'
--- bzrlib/bundle/serializer/v08.py	2007-06-20 00:25:11 +0000
+++ bzrlib/bundle/serializer/v08.py	2008-04-24 07:22:53 +0000
@@ -146,7 +146,8 @@
             If this parameter is True, and value is the empty string, we will
             write an extra space.
         """
-        assert indent > 0, 'indentation must be greater than 0'
+        if indent < 1:
+            raise ValueError('indentation must be greater than 0')
         f = self.to_file
         f.write('#' + (' ' * indent))
         f.write(key.encode('utf-8'))
@@ -523,7 +524,8 @@
             action, lines, do_continue = self._read_one_patch()
             if action is not None:
                 revision_actions.append((action, lines))
-        assert self.info.revisions[-1].tree_actions is None
+        if self.info.revisions[-1].tree_actions is not None:
+            raise AssertionError()
         self.info.revisions[-1].tree_actions = revision_actions
 
     def _read_footer(self):

=== modified file 'bzrlib/bundle/serializer/v4.py'
--- bzrlib/bundle/serializer/v4.py	2008-03-19 04:39:04 +0000
+++ bzrlib/bundle/serializer/v4.py	2008-04-24 07:22:53 +0000
@@ -107,17 +107,20 @@
     @staticmethod
     def encode_name(content_kind, revision_id, file_id=None):
         """Encode semantic ids as a container name"""
-        assert content_kind in ('revision', 'file', 'inventory', 'signature',
-                                'info')
-
+        if content_kind not in ('revision', 'file', 'inventory', 'signature',
+                'info'):
+            raise ValueError(content_kind)
         if content_kind == 'file':
-            assert file_id is not None
+            if file_id is None:
+                raise AssertionError()
         else:
-            assert file_id is None
+            if file_id is not None:
+                raise AssertionError()
         if content_kind == 'info':
-            assert revision_id is None
-        else:
-            assert revision_id is not None
+            if revision_id is not None:
+                raise AssertionError()
+        elif revision_id is None:
+            raise AssertionError()
         names = [n.replace('/', '//') for n in
                  (content_kind, revision_id, file_id) if n is not None]
         return '/'.join(names)
@@ -494,7 +497,8 @@
         for bytes, metadata, repo_kind, revision_id, file_id in\
             self._container.iter_records():
             if repo_kind == 'info':
-                assert self._info is None
+                if self._info is not None:
+                    raise AssertionError()
                 self._handle_info(metadata)
             if (repo_kind, file_id) != ('file', current_file):
                 if len(pending_file_records) > 0:

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2008-04-14 08:03:35 +0000
+++ bzrlib/bzrdir.py	2008-04-24 07:22:53 +0000
@@ -1039,8 +1039,6 @@
     def __init__(self, _transport, _format):
         """See BzrDir.__init__."""
         super(BzrDirPreSplitOut, self).__init__(_transport, _format)
-        assert self._format._lock_class == lockable_files.TransportLock
-        assert self._format._lock_file_name == 'branch-lock'
         self._control_files = lockable_files.LockableFiles(
                                             self.get_branch_transport(None),
                                             self._format._lock_file_name,
@@ -1647,7 +1645,6 @@
 
     @classmethod
     def unregister_format(klass, format):
-        assert klass._formats[format.get_format_string()] is format
         del klass._formats[format.get_format_string()]
 
     @classmethod
@@ -2077,18 +2074,13 @@
             self.revisions[rev_id] = rev
 
     def _load_old_inventory(self, rev_id):
-        assert rev_id not in self.converted_revs
         old_inv_xml = self.branch.repository.inventory_store.get(rev_id).read()
         inv = xml4.serializer_v4.read_inventory_from_string(old_inv_xml)
         inv.revision_id = rev_id
         rev = self.revisions[rev_id]
-        if rev.inventory_sha1:
-            assert rev.inventory_sha1 == sha_string(old_inv_xml), \
-                'inventory sha mismatch for {%s}' % rev_id
         return inv
 
     def _load_updated_inventory(self, rev_id):
-        assert rev_id in self.converted_revs
         inv_xml = self.inv_weave.get_text(rev_id)
         inv = xml5.serializer_v5.read_inventory_from_string(inv_xml, rev_id)
         return inv
@@ -2104,14 +2096,6 @@
         self.converted_revs.add(rev_id)
 
     def _store_new_inv(self, rev, inv, present_parents):
-        # the XML is now updated with text versions
-        if __debug__:
-            entries = inv.iter_entries()
-            entries.next()
-            for path, ie in entries:
-                assert getattr(ie, 'revision', None) is not None, \
-                    'no revision on {%s} in {%s}' % \
-                    (file_id, rev.revision_id)
         new_inv_xml = xml5.serializer_v5.write_inventory_to_string(inv)
         new_inv_sha1 = sha_string(new_inv_xml)
         self.inv_weave.add_lines(rev.revision_id,
@@ -2146,10 +2130,6 @@
             self.text_weaves[file_id] = w
         text_changed = False
         parent_candiate_entries = ie.parent_candidates(parent_invs)
-        for old_revision in parent_candiate_entries.keys():
-            # if this fails, its a ghost ?
-            assert old_revision in self.converted_revs, \
-                "Revision {%s} not in converted_revs" % old_revision
         heads = graph.Graph(self).heads(parent_candiate_entries.keys())
         # XXX: Note that this is unordered - and this is tolerable because 
         # the previous code was also unordered.
@@ -2157,7 +2137,6 @@
             in heads)
         self.snapshot_ie(previous_entries, ie, w, rev_id)
         del ie.text_id
-        assert getattr(ie, 'revision', None) is not None
 
     @symbol_versioning.deprecated_method(symbol_versioning.one_one)
     def get_parents(self, revision_ids):
@@ -2186,8 +2165,6 @@
         if ie.has_text():
             text = self.branch.repository.weave_store.get(ie.text_id)
             file_lines = text.readlines()
-            assert sha_strings(file_lines) == ie.text_sha1
-            assert sum(map(len, file_lines)) == ie.text_size
             w.add_lines(rev_id, previous_revisions, file_lines)
             self.text_count += 1
         else:
@@ -2467,7 +2444,8 @@
         client = _SmartClient(client_medium, transport.base)
         path = client.remote_path_from_transport(transport)
         response = client.call('BzrDirFormat.initialize', path)
-        assert response[0] in ('ok', ), 'unexpected response code %s' % (response,)
+        if response[0] != 'ok':
+            raise errors.SmartProtocolError('unexpected response code %s' % (response,))
         return remote.RemoteBzrDir(transport)
 
     def _open(self, transport):
@@ -2595,7 +2573,6 @@
             self.remove('default')
         self.set_default(key)
         format = self.get('default')()
-        assert isinstance(format, BzrDirMetaFormat1)
 
     def make_bzrdir(self, key):
         return self.get(key)()

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2008-04-08 22:56:38 +0000
+++ bzrlib/commands.py	2008-04-24 07:22:53 +0000
@@ -95,7 +95,6 @@
 
 
 def _unsquish_command_name(cmd):
-    assert cmd.startswith("cmd_")
     return cmd[4:].replace('_','-')
 
 
@@ -283,9 +282,7 @@
             elif aname[-1] == '*':
                 aname = '[' + aname[:-1] + '...]'
             s += aname + ' '
-                
-        assert s[-1] == ' '
-        s = s[:-1]
+        s = s[:-1]      # remove last space
         return s
 
     def get_help_text(self, additional_see_also=None, plain=True,
@@ -445,8 +442,6 @@
 
     def _setup_outf(self):
         """Return a file linked to stdout, which has proper encoding."""
-        assert self.encoding_type in ['strict', 'exact', 'replace']
-
         # Originally I was using self.stdout, but that looks
         # *way* too much like sys.stdout
         if self.encoding_type == 'exact':

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2007-12-21 06:34:27 +0000
+++ bzrlib/commit.py	2008-04-24 07:22:53 +0000
@@ -365,7 +365,6 @@
 
                 # Prompt the user for a commit message if none provided
                 message = message_callback(self)
-                assert isinstance(message, unicode), type(message)
                 self.message = message
                 self._escape_commit_message()
 

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2008-04-13 17:38:34 +0000
+++ bzrlib/config.py	2008-04-24 07:22:53 +0000
@@ -570,9 +570,11 @@
 
     def set_user_option(self, option, value, store=STORE_LOCATION):
         """Save option and its value in the configuration."""
-        assert store in [STORE_LOCATION,
+        if store not in [STORE_LOCATION,
                          STORE_LOCATION_NORECURSE,
-                         STORE_LOCATION_APPENDPATH], 'bad storage policy'
+                         STORE_LOCATION_APPENDPATH]:
+            raise ValueError('bad storage policy %r for %r' %
+                (store, option))
         # FIXME: RBC 20051029 This should refresh the parser and also take a
         # file lock on locations.conf.
         conf_dir = os.path.dirname(self._get_filename())

=== modified file 'bzrlib/counted_lock.py'
--- bzrlib/counted_lock.py	2007-05-02 14:00:53 +0000
+++ bzrlib/counted_lock.py	2008-04-24 07:22:53 +0000
@@ -56,11 +56,8 @@
         it is taken in read mode.
         """
         if self._lock_mode:
-            assert self._lock_mode in ('r', 'w'), \
-                   "invalid lock mode %r" % self._lock_mode
             self._lock_count += 1
         else:
-            assert self._lock_count == 0
             self._real_lock.lock_read()
             self._lock_count = 1
             self._lock_mode = 'r'
@@ -71,7 +68,6 @@
         If the lock was originally acquired in read mode this will fail.
         """
         if self._lock_count == 0:
-            assert self._lock_mode is None
             self._real_lock.lock_write()
             self._lock_mode = 'w'
         elif self._lock_mode != 'w':

=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2008-03-07 14:15:10 +0000
+++ bzrlib/delta.py	2008-04-24 07:22:53 +0000
@@ -226,7 +226,6 @@
             if fully_present[1] is True:
                 delta.added.append((path[1], file_id, kind[1]))
             else:
-                assert fully_present[0] is True
                 delta.removed.append((path[0], file_id, kind[0]))
         elif fully_present[0] is False:
             continue

=== modified file 'bzrlib/deprecated_graph.py'
--- bzrlib/deprecated_graph.py	2008-03-01 09:11:39 +0000
+++ bzrlib/deprecated_graph.py	2008-04-24 07:22:53 +0000
@@ -57,7 +57,6 @@
         new_lines = set()
         for line in lines:
             line_descendants = graph[line]
-            assert line not in line_descendants, "%s refers to itself" % line
             for descendant in line_descendants:
                 distance = max_distance(descendant, ancestors, distances,
                                         root_descendants)

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2008-04-03 00:37:18 +0000
+++ bzrlib/diff.py	2008-04-24 07:22:53 +0000
@@ -323,8 +323,6 @@
         return branch.repository.revision_tree(revision_id)
 
     if revision_specs is not None:
-        assert (old_revision_spec is None
-                and new_revision_spec is None)
         if len(revision_specs) > 0:
             old_revision_spec = revision_specs[0]
         if len(revision_specs) > 1:
@@ -516,9 +514,6 @@
 def _patch_header_date(tree, file_id, path):
     """Returns a timestamp suitable for use in a patch header."""
     mtime = tree.get_file_mtime(file_id, path)
-    assert mtime is not None, \
-        "got an mtime of None for file-id %s, path %s in tree %s" % (
-                file_id, path, tree)
     return timestamp.format_patch_date(mtime)
 
 
@@ -913,7 +908,6 @@
         else:
             extra_factories = []
         if external_diff_options:
-            assert isinstance(external_diff_options, basestring)
             opts = external_diff_options.split()
             def diff_file(olab, olines, nlab, nlines, to_file):
                 external_diff(olab, olines, nlab, nlines, to_file, opts)

=== modified file 'bzrlib/dirstate.py'
--- bzrlib/dirstate.py	2008-03-06 18:21:43 +0000
+++ bzrlib/dirstate.py	2008-04-24 07:22:53 +0000
@@ -393,8 +393,9 @@
         # faster than three separate encodes.
         utf8path = (dirname + '/' + basename).strip('/').encode('utf8')
         dirname, basename = osutils.split(utf8path)
-        assert file_id.__class__ == str, \
-            "must be a utf8 file_id not %s" % (type(file_id))
+        if file_id.__class__ != str:
+            raise AssertionError(
+                "must be a utf8 file_id not %s" % (type(file_id), ))
         # Make sure the file_id does not exist in this tree
         file_id_entry = self._get_entry(0, fileid_utf8=file_id)
         if file_id_entry != (None, None):
@@ -456,7 +457,8 @@
         if not present:
             block.insert(entry_index, entry_data)
         else:
-            assert block[entry_index][1][0][0] == 'a', " %r(%r) already added" % (basename, file_id)
+            if block[entry_index][1][0][0] != 'a':
+                raise AssertionError(" %r(%r) already added" % (basename, file_id))
             block[entry_index][1][0] = entry_data[1][0]
 
         if kind == 'directory':
@@ -481,7 +483,8 @@
         # If _dirblock_state was in memory, we should just return info from
         # there, this function is only meant to handle when we want to read
         # part of the disk.
-        assert self._dirblock_state == DirState.NOT_IN_MEMORY
+        if self._dirblock_state != DirState.NOT_IN_MEMORY:
+            raise AssertionError("bad dirblock state %r" % self._dirblock_state)
 
         # The disk representation is generally info + '\0\n\0' at the end. But
         # for bisecting, it is easier to treat this as '\0' + info + '\0\n'
@@ -673,8 +676,8 @@
         # If _dirblock_state was in memory, we should just return info from
         # there, this function is only meant to handle when we want to read
         # part of the disk.
-        assert self._dirblock_state == DirState.NOT_IN_MEMORY
-
+        if self._dirblock_state != DirState.NOT_IN_MEMORY:
+            raise AssertionError("bad dirblock state %r" % self._dirblock_state)
         # The disk representation is generally info + '\0\n\0' at the end. But
         # for bisecting, it is easier to treat this as '\0' + info + '\0\n'
         # Because it means we can sync on the '\n'
@@ -967,8 +970,9 @@
         # the basename of the directory must be the end of its full name.
         if not (parent_block_index == -1 and
             parent_block_index == -1 and dirname == ''):
-            assert dirname.endswith(
-                self._dirblocks[parent_block_index][1][parent_row_index][0][1])
+            if not dirname.endswith(
+                    self._dirblocks[parent_block_index][1][parent_row_index][0][1]):
+                raise AssertionError("bad dirname %r" % dirname)
         block_index, present = self._find_block_index_from_key((dirname, '', ''))
         if not present:
             ## In future, when doing partial parsing, this should load and 
@@ -986,8 +990,9 @@
             to prevent unneeded overhead when callers have a sorted list already.
         :return: Nothing.
         """
-        assert new_entries[0][0][0:2] == ('', ''), \
-            "Missing root row %r" % (new_entries[0][0],)
+        if new_entries[0][0][0:2] != ('', ''):
+            raise AssertionError(
+                "Missing root row %r" % (new_entries[0][0],))
         # The two blocks here are deliberate: the root block and the 
         # contents-of-root block.
         self._dirblocks = [('', []), ('', [])]
@@ -1015,7 +1020,8 @@
         # The above loop leaves the "root block" entries mixed with the
         # "contents-of-root block". But we don't want an if check on
         # all entries, so instead we just fix it up here.
-        assert self._dirblocks[1] == ('', [])
+        if self._dirblocks[1] != ('', []):
+            raise ValueError("bad dirblock start %r" % (self._dirblocks[1],))
         root_block = []
         contents_of_root_block = []
         for entry in self._dirblocks[0][1]:
@@ -1175,10 +1181,9 @@
         self._read_dirblocks_if_needed()
         insertions = {}
         removals = {}
-        for old_path, new_path, file_id, inv_entry in sorted(delta,
-                                                             reverse=True):
-            assert file_id not in insertions
-            assert file_id not in removals
+        for old_path, new_path, file_id, inv_entry in sorted(delta, reverse=True):
+            if (file_id in insertions) or (file_id in removals):
+                raise AssertionError("repeated file id in delta %r" % (file_id,))
             if old_path is not None:
                 old_path = old_path.encode('utf-8')
                 removals[file_id] = old_path
@@ -1315,8 +1320,9 @@
                     if new_path_utf8:
                         target_path = new_path_utf8 + source_path[len(old_path):]
                     else:
-                        assert len(old_path) > 0, ("cannot rename directory to"
-                                                   " itself")
+                        if old_path == '':
+                            raise AssertionError("cannot rename directory to"
+                                " itself")
                         target_path = source_path[len(old_path) + 1:]
                     adds.append((None, target_path, entry[0][2], entry[1][1], False))
                     deletes.append(
@@ -1359,7 +1365,6 @@
         # their children, so we can process it linearly.
         absent = 'ar'
         for old_path, new_path, file_id, new_details, real_add in adds:
-            assert old_path is None
             # the entry for this file_id must be in tree 0.
             entry = self._get_entry(0, file_id, new_path)
             if entry[0] is None or entry[0][2] != file_id:
@@ -1384,7 +1389,6 @@
         """
         absent = 'ar'
         for old_path, new_path, file_id, new_details in changes:
-            assert old_path == new_path
             # the entry for this file_id must be in tree 0.
             entry = self._get_entry(0, file_id, new_path)
             if entry[0] is None or entry[0][2] != file_id:
@@ -1412,10 +1416,8 @@
         """
         null = DirState.NULL_PARENT_DETAILS
         for old_path, new_path, file_id, _, real_delete in deletes:
-            if real_delete:
-                assert new_path is None
-            else:
-                assert new_path is not None
+            if real_delete != (new_path is None):
+                raise AssertionError("bad delete delta")
             # the entry for this file_id must be in tree 1.
             dirname, basename = osutils.split(old_path)
             block_index, entry_index, dir_present, file_present = \
@@ -1736,8 +1738,9 @@
         """
         self._read_dirblocks_if_needed()
         if path_utf8 is not None:
-            assert path_utf8.__class__ == str, ('path_utf8 is not a str: %s %s'
-                % (type(path_utf8), path_utf8))
+            if not isinstance(path_utf8, str):
+                raise AssertionError('path_utf8 is not a str: %s %s'
+                    % (type(path_utf8), path_utf8))
             # path lookups are faster
             dirname, basename = osutils.split(path_utf8)
             block_index, entry_index, dir_present, file_present = \
@@ -1745,7 +1748,8 @@
             if not file_present:
                 return None, None
             entry = self._dirblocks[block_index][1][entry_index]
-            assert entry[0][2] and entry[1][tree_index][0] not in ('a', 'r'), 'unversioned entry?!?!'
+            if not (entry[0][2] and entry[1][tree_index][0] not in ('a', 'r')):
+                raise AssertionError('unversioned entry?')
             if fileid_utf8:
                 if entry[0][2] != fileid_utf8:
                     self._changes_aborted = True
@@ -1753,7 +1757,6 @@
                                           ' tree_index, file_id and path')
             return entry
         else:
-            assert fileid_utf8 is not None
             possible_keys = self._get_id_index().get(fileid_utf8, None)
             if not possible_keys:
                 return None, None
@@ -1778,11 +1781,12 @@
                     if entry[1][tree_index][0] == 'a':
                         # there is no home for this entry in this tree
                         return None, None
-                    assert entry[1][tree_index][0] == 'r', \
-                        "entry %r has invalid minikind %r for tree %r" \
-                        % (entry,
-                           entry[1][tree_index][0],
-                           tree_index)
+                    if entry[1][tree_index][0] != 'r':
+                        raise AssertionError(
+                            "entry %r has invalid minikind %r for tree %r" \
+                            % (entry,
+                               entry[1][tree_index][0],
+                               tree_index))
                     real_path = entry[1][tree_index][1]
                     return self._get_entry(tree_index, fileid_utf8=fileid_utf8,
                         path_utf8=real_path)
@@ -1831,8 +1835,6 @@
         kind = inv_entry.kind
         minikind = DirState._kind_to_minikind[kind]
         tree_data = inv_entry.revision
-        assert tree_data, 'empty revision for the inv_entry %s.' % \
-            inv_entry.file_id
         if kind == 'directory':
             fingerprint = ''
             size = 0
@@ -1971,13 +1973,10 @@
         parent_line = self._state_file.readline()
         info = parent_line.split('\0')
         num_parents = int(info[0])
-        assert num_parents == len(info)-2, 'incorrect parent info line'
         self._parents = info[1:-1]
-
         ghost_line = self._state_file.readline()
         info = ghost_line.split('\0')
         num_ghosts = int(info[1])
-        assert num_ghosts == len(info)-3, 'incorrect ghost info line'
         self._ghosts = info[2:-1]
         self._header_state = DirState.IN_MEMORY_UNMODIFIED
         self._end_of_header = self._state_file.tell()
@@ -2000,13 +1999,16 @@
         and their ids. Followed by a newline.
         """
         header = self._state_file.readline()
-        assert header == DirState.HEADER_FORMAT_3, \
-            'invalid header line: %r' % (header,)
+        if header != DirState.HEADER_FORMAT_3:
+            raise errors.BzrError(
+                'invalid header line: %r' % (header,))
         crc_line = self._state_file.readline()
-        assert crc_line.startswith('crc32: '), 'missing crc32 checksum'
+        if not crc_line.startswith('crc32: '):
+            raise errors.BzrError('missing crc32 checksum: %r' % crc_line)
         self.crc_expected = int(crc_line[len('crc32: '):-1])
         num_entries_line = self._state_file.readline()
-        assert num_entries_line.startswith('num_entries: '), 'missing num_entries line'
+        if not num_entries_line.startswith('num_entries: '):
+            raise errors.BzrError('missing num_entries line')
         self._num_entries = int(num_entries_line[len('num_entries: '):-1])
 
     def sha1_from_stat(self, path, stat_result, _pack_stat=pack_stat):
@@ -2100,8 +2102,6 @@
         :param new_id: The new id to assign to the path. This must be a utf8
             file id (not unicode, and not None).
         """
-        assert new_id.__class__ == str, \
-            "path_id %r is not a plain string" % (new_id,)
         self._read_dirblocks_if_needed()
         if len(path):
             # TODO: logic not written
@@ -2403,7 +2403,8 @@
             # Remove it, its meaningless.
             block = self._find_block(current_old[0])
             entry_index, present = self._find_entry_index(current_old[0], block[1])
-            assert present, 'could not find entry for %s' % (current_old,)
+            if not present:
+                raise AssertionError('could not find entry for %s' % (current_old,))
             block[1].pop(entry_index)
             # if we have an id_index in use, remove this key from it for this id.
             if self._id_index is not None:
@@ -2415,13 +2416,16 @@
         for update_key in all_remaining_keys:
             update_block_index, present = \
                 self._find_block_index_from_key(update_key)
-            assert present, 'could not find block for %s' % (update_key,)
+            if not present:
+                raise AssertionError('could not find block for %s' % (update_key,))
             update_entry_index, present = \
                 self._find_entry_index(update_key, self._dirblocks[update_block_index][1])
-            assert present, 'could not find entry for %s' % (update_key,)
+            if not present:
+                raise AssertionError('could not find entry for %s' % (update_key,))
             update_tree_details = self._dirblocks[update_block_index][1][update_entry_index][1]
             # it must not be absent at the moment
-            assert update_tree_details[0][0] != 'a' # absent
+            if update_tree_details[0][0] == 'a': # absent
+                raise AssertionError('bad row %r' % (update_tree_details,))
             update_tree_details[0] = DirState.NULL_PARENT_DETAILS
         self._dirblock_state = DirState.IN_MEMORY_MODIFIED
         return last_reference
@@ -2475,11 +2479,14 @@
                     # the test for existing kinds is different: this can be
                     # factored out to a helper though.
                     other_block_index, present = self._find_block_index_from_key(other_key)
-                    assert present, 'could not find block for %s' % (other_key,)
+                    if not present:
+                        raise AssertionError('could not find block for %s' % (other_key,))
                     other_entry_index, present = self._find_entry_index(other_key,
                                             self._dirblocks[other_block_index][1])
-                    assert present, 'could not find entry for %s' % (other_key,)
-                    assert path_utf8 is not None
+                    if not present:
+                        raise AssertionError('could not find entry for %s' % (other_key,))
+                    if path_utf8 is None:
+                        raise AssertionError('no path')
                     self._dirblocks[other_block_index][1][other_entry_index][1][0] = \
                         ('r', path_utf8, 0, False, '')
 
@@ -2491,10 +2498,12 @@
                     # records.
                     update_block_index, present = \
                         self._find_block_index_from_key(other_key)
-                    assert present, 'could not find block for %s' % (other_key,)
+                    if not present:
+                        raise AssertionError('could not find block for %s' % (other_key,))
                     update_entry_index, present = \
                         self._find_entry_index(other_key, self._dirblocks[update_block_index][1])
-                    assert present, 'could not find entry for %s' % (other_key,)
+                    if not present:
+                        raise AssertionError('could not find entry for %s' % (other_key,))
                     update_details = self._dirblocks[update_block_index][1][update_entry_index][1][lookup_index]
                     if update_details[0] in 'ar': # relocated, absent
                         # its a pointer or absent in lookup_index's tree, use
@@ -2518,7 +2527,8 @@
             # we may have passed entries in the state with this file id already
             # that were absent - where parent entries are - and they need to be
             # converted to relocated.
-            assert path_utf8 is not None
+            if path_utf8 is None:
+                raise AssertionError('no path')
             for entry_key in id_index.setdefault(key[2], set()):
                 # TODO:PROFILING: It might be faster to just update
                 # rather than checking if we need to, and then overwrite
@@ -2529,9 +2539,11 @@
                     # This is the vertical axis in the matrix, all pointing
                     # to the real path.
                     block_index, present = self._find_block_index_from_key(entry_key)
-                    assert present
+                    if not present:
+                        raise AssertionError('not present: %r', entry_key)
                     entry_index, present = self._find_entry_index(entry_key, self._dirblocks[block_index][1])
-                    assert present
+                    if not present:
+                        raise AssertionError('not present: %r', entry_key)
                     self._dirblocks[block_index][1][entry_index][1][0] = \
                         ('r', path_utf8, 0, False, '')
         # add a containing dirblock if needed.

=== modified file 'bzrlib/hashcache.py'
--- bzrlib/hashcache.py	2007-02-26 01:06:36 +0000
+++ bzrlib/hashcache.py	2008-04-24 07:22:53 +0000
@@ -210,7 +210,6 @@
             outf.write(CACHE_HEADER)
 
             for path, c  in self._cache.iteritems():
-                assert '//' not in path, path
                 line_info = [path.encode('utf-8'), '// ', c[0], ' ']
                 line_info.append(' '.join([str(fld) for fld in c[1]]))
                 line_info.append('\n')

=== modified file 'bzrlib/index.py'
--- bzrlib/index.py	2007-12-18 19:42:10 +0000
+++ bzrlib/index.py	2008-04-24 07:22:53 +0000
@@ -830,7 +830,8 @@
                 trim_start = data.find('\n') + 1
             else:
                 trim_start = data.find('\n', trim_start) + 1
-            assert trim_start != 0, 'no \n was present'
+            if not (trim_start != 0):
+                raise AssertionError('no \n was present')
             # print 'removing start', offset, trim_start, repr(data[:trim_start])
         if not end_adjacent:
             # work around python bug in rfind
@@ -838,12 +839,14 @@
                 trim_end = data.rfind('\n') + 1
             else:
                 trim_end = data.rfind('\n', None, trim_end) + 1
-            assert trim_end != 0, 'no \n was present'
+            if not (trim_end != 0):
+                raise AssertionError('no \n was present')
             # print 'removing end', offset, trim_end, repr(data[trim_end:])
         # adjust offset and data to the parseable data.
         trimmed_data = data[trim_start:trim_end]
-        assert trimmed_data, 'read unneeded data [%d:%d] from [%d:%d]' % (
-            trim_start, trim_end, offset, offset + len(data))
+        if not (trimmed_data):
+            raise AssertionError('read unneeded data [%d:%d] from [%d:%d]' 
+                % (trim_start, trim_end, offset, offset + len(data)))
         if trim_start:
             offset += trim_start
         # print "parsing", repr(trimmed_data)
@@ -867,7 +870,8 @@
             if line == '':
                 # must be at the end
                 if self._size:
-                    assert self._size == pos + 1, "%s %s" % (self._size, pos)
+                    if not (self._size == pos + 1):
+                        raise AssertionError("%s %s" % (self._size, pos))
                 trailers += 1
                 continue
             elements = line.split('\0')
@@ -958,7 +962,8 @@
             for offset, data in readv_data:
                 if self._bisect_nodes is None:
                     # this must be the start
-                    assert offset == 0
+                    if not (offset == 0):
+                        raise AssertionError()
                     offset, data = self._parse_header_from_bytes(data)
                 # print readv_ranges, "[%d:%d]" % (offset, offset + len(data))
                 self._parse_region(offset, data)

=== modified file 'bzrlib/intset.py'
--- bzrlib/intset.py	2006-09-08 18:46:29 +0000
+++ bzrlib/intset.py	2008-04-24 07:22:53 +0000
@@ -149,7 +149,6 @@
 
 
     def __contains__(self, i):
-        assert i >= 0
         return self._val & (1L << i)
 
 
@@ -177,12 +176,10 @@
             self._val |= to_add._val
         else:
             for i in to_add:
-                assert i >= 0
                 self._val |= (1L << i)
 
 
     def add(self, to_add):
-        assert 0 <= to_add
         self._val |= (1L << to_add)
 
 
@@ -203,7 +200,6 @@
         >>> not a
         True
         """
-        assert 0 <= to_remove
         m = 1L << to_remove
         if not self._val & m:
             raise KeyError(to_remove)

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2008-04-08 03:39:43 +0000
+++ bzrlib/inventory.py	2008-04-24 07:22:53 +0000
@@ -112,7 +112,6 @@
     InventoryFile('2326', 'wibble.c', parent_id='2325', sha1=None, len=None)
     >>> for path, entry in i.iter_entries():
     ...     print path
-    ...     assert i.path2id(path)
     ... 
     <BLANKLINE>
     src
@@ -142,24 +141,6 @@
         """
         return False, False
 
-    @deprecated_method(symbol_versioning.one_zero)
-    def diff(self, text_diff, from_label, tree, to_label, to_entry, to_tree,
-             output_to, reverse=False):
-        """Perform a diff from this to to_entry.
-
-        text_diff will be used for textual difference calculation.
-        This is a template method, override _diff in child classes.
-        """
-        self._read_tree_state(tree.id2path(self.file_id), tree)
-        if to_entry:
-            # cannot diff from one kind to another - you must do a removal
-            # and an addif they do not match.
-            assert self.kind == to_entry.kind
-            to_entry._read_tree_state(to_tree.id2path(to_entry.file_id),
-                                      to_tree)
-        self._diff(text_diff, from_label, tree, to_label, to_entry, to_tree,
-                   output_to, reverse)
-
     def _diff(self, text_diff, from_label, tree, to_label, to_entry, to_tree,
              output_to, reverse=False):
         """Perform a diff between two entries of the same kind."""
@@ -179,7 +160,6 @@
         for inv in previous_inventories:
             if self.file_id in inv:
                 ie = inv[self.file_id]
-                assert ie.file_id == self.file_id
                 if ie.revision in candidates:
                     # same revision value in two different inventories:
                     # correct possible inconsistencies:
@@ -191,8 +171,6 @@
                             ie.executable = False
                     except AttributeError:
                         pass
-                    # must now be the same.
-                    assert candidates[ie.revision] == ie
                 else:
                     # add this revision as a candidate.
                     candidates[ie.revision] = ie
@@ -303,7 +281,6 @@
         Traceback (most recent call last):
         InvalidEntryName: Invalid entry name: src/hello.c
         """
-        assert isinstance(name, basestring), name
         if '/' in name or '\\' in name:
             raise errors.InvalidEntryName(name=name)
         self.executable = False
@@ -311,8 +288,6 @@
         self.text_sha1 = None
         self.text_size = None
         self.file_id = file_id
-        assert isinstance(file_id, (str, None.__class__)), \
-            'bad type %r for %r' % (type(file_id), file_id)
         self.name = name
         self.text_id = text_id
         self.parent_id = parent_id
@@ -611,8 +586,6 @@
 
     def detect_changes(self, old_entry):
         """See InventoryEntry.detect_changes."""
-        assert self.text_sha1 is not None
-        assert old_entry.text_sha1 is not None
         text_modified = (self.text_sha1 != old_entry.text_sha1)
         meta_modified = (self.executable != old_entry.executable)
         return text_modified, meta_modified
@@ -868,7 +841,6 @@
         an id of None.
         """
         if root_id is not None:
-            assert root_id.__class__ == str
             self._set_root(InventoryDirectory(root_id, u'', None))
         else:
             self.root = None
@@ -1173,7 +1145,6 @@
                                          self._byid[entry.file_id])
 
         if entry.parent_id is None:
-            assert self.root is None and len(self._byid) == 0
             self.root = entry
         else:
             try:
@@ -1225,10 +1196,6 @@
         False
         """
         ie = self[file_id]
-
-        assert ie.parent_id is None or \
-            self[ie.parent_id].children[ie.name] == ie
-        
         del self._byid[file_id]
         if ie.parent_id is not None:
             del self[ie.parent_id].children[ie.name]
@@ -1322,8 +1289,6 @@
                 if children is None:
                     return None
                 cie = children[f]
-                assert cie.name == f
-                assert cie.parent_id == parent.file_id
                 parent = cie
             except KeyError:
                 # or raise an error?

=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2008-04-09 23:35:55 +0000
+++ bzrlib/knit.py	2008-04-24 07:22:53 +0000
@@ -301,7 +301,6 @@
         """
         method, noeol = record_details
         if method == 'line-delta':
-            assert base_content is not None
             if copy_base_content:
                 content = base_content.copy()
             else:
@@ -693,8 +692,8 @@
                 # put them in anywhere, but we hope that sending them soon
                 # after the fulltext will give good locality in the receiver
                 ready_to_send[:0] = deferred.pop(version_id)
-        assert len(deferred) == 0, \
-            "Still have compressed child versions waiting to be sent"
+        if not (len(deferred) == 0):
+            raise AssertionError("Still have compressed child versions waiting to be sent")
         # XXX: The stream format is such that we cannot stream it - we have to
         # know the length of all the data a-priori.
         raw_datum = []
@@ -703,8 +702,8 @@
             (version_id2, options, _, parents) in \
             izip(self._data.read_records_iter_raw(copy_queue_records),
                  temp_version_list):
-            assert version_id == version_id2, \
-                'logic error, inconsistent results'
+            if not (version_id == version_id2):
+                raise AssertionError('logic error, inconsistent results')
             raw_datum.append(raw_data)
             result_version_list.append(
                 (version_id, options, len(raw_data), parents))
@@ -1049,7 +1048,6 @@
             # I/O and the time spend applying deltas.
             delta = self._check_should_delta(present_parents)
 
-        assert isinstance(version_id, str)
         content = self.factory.make(lines, version_id)
         if delta or (self.factory.annotated and len(present_parents) > 0):
             # Merge annotations from parent texts if needed.
@@ -1215,12 +1213,12 @@
             enumerate(self._data.read_records_iter(version_id_records)):
             pb.update('Walking content.', version_idx, total)
             method = self._index.get_method(version_id)
-
-            assert method in ('fulltext', 'line-delta')
             if method == 'fulltext':
                 line_iterator = self.factory.get_fulltext_content(data)
-            else:
+            elif method == 'line-delta':
                 line_iterator = self.factory.get_linedelta_content(data)
+            else:
+                raise ValueError('invalid method %r' % (method,))
             # XXX: It might be more efficient to yield (version_id,
             # line_iterator) in the future. However for now, this is a simpler
             # change to integrate into the rest of the codebase. RBC 20071110
@@ -1537,8 +1535,6 @@
                                                pos,
                                                size,
                                                self._version_list_to_index(parents))
-                assert isinstance(line, str), \
-                    'content must be utf-8 encoded: %r' % (line,)
                 lines.append(line)
                 self._cache_version(version_id, options, pos, size, tuple(parents))
             if not self._need_to_create:
@@ -1804,7 +1800,6 @@
         compression_parents = an_entry[3][1]
         if not compression_parents:
             return None
-        assert len(compression_parents) == 1
         return compression_parents[0]
 
     def _get_method(self, node):
@@ -1991,8 +1986,6 @@
             tuple - (index, pos, length), where the index field is always None
             for the .knit access method.
         """
-        assert type(raw_data) == str, \
-            'data must be plain bytes was %s' % type(raw_data)
         if not self._need_to_create:
             base = self._transport.append_bytes(self._filename, raw_data)
         else:
@@ -2075,8 +2068,6 @@
             tuple - (index, pos, length), where the index field is the 
             write_index object supplied to the PackAccess object.
         """
-        assert type(raw_data) == str, \
-            'data must be plain bytes was %s' % type(raw_data)
         result = []
         offset = 0
         for size in sizes:
@@ -2175,7 +2166,8 @@
         # use a generator for memory friendliness
         for from_backing_knit, version_id, start, end in memos_for_retrieval:
             if not from_backing_knit:
-                assert version_id is self.stream_index
+                if version_id is not self.stream_index:
+                    raise AssertionError()
                 yield self.data[start:end]
                 continue
             # we have been asked to thunk. This thunking only occurs when
@@ -2402,7 +2394,6 @@
                                      digest)],
             dense_lines or lines,
             ["end %s\n" % version_id]))
-        assert bytes.__class__ == str
         compressed_bytes = bytes_to_gzip(bytes)
         return len(compressed_bytes), compressed_bytes
 
@@ -2590,9 +2581,6 @@
 
     def join(self, pb=None, msg=None, version_ids=None, ignore_missing=False):
         """See InterVersionedFile.join."""
-        assert isinstance(self.source, KnitVersionedFile)
-        assert isinstance(self.target, KnitVersionedFile)
-
         # If the source and target are mismatched w.r.t. annotations vs
         # plain, the data needs to be converted accordingly
         if self.source.factory.annotated == self.target.factory.annotated:
@@ -2644,9 +2632,12 @@
                     # * already have it or
                     # * have it scheduled already
                     # otherwise we don't care
-                    assert (self.target.has_version(parent) or
+                    if not (self.target.has_version(parent) or
                             parent in copy_set or
-                            not self.source.has_version(parent))
+                            not self.source.has_version(parent)):
+                        raise AssertionError("problem joining parent %r "
+                            "from %r to %r"
+                            % (parent, self.source, self.target))
                 index_memo = self.source._index.get_position(version_id)
                 copy_queue_records.append((version_id, index_memo))
                 copy_queue.append((version_id, options, parents))
@@ -2661,7 +2652,8 @@
                 (version_id2, options, parents) in \
                 izip(self.source._data.read_records_iter_raw(copy_queue_records),
                      copy_queue):
-                assert version_id == version_id2, 'logic error, inconsistent results'
+                if not (version_id == version_id2):
+                    raise AssertionError('logic error, inconsistent results')
                 count = count + 1
                 pb.update("Joining knit", count, total)
                 if converter:
@@ -2710,9 +2702,6 @@
 
     def join(self, pb=None, msg=None, version_ids=None, ignore_missing=False):
         """See InterVersionedFile.join."""
-        assert isinstance(self.source, bzrlib.weave.Weave)
-        assert isinstance(self.target, KnitVersionedFile)
-
         version_ids = self._get_source_version_ids(version_ids, ignore_missing)
 
         if not version_ids:
@@ -2744,7 +2733,9 @@
                 # check that its will be a consistent copy:
                 for parent in parents:
                     # if source has the parent, we must already have it
-                    assert (self.target.has_version(parent))
+                    if not self.target.has_version(parent):
+                        raise AssertionError("%r does not have parent %r"
+                            % (self.target, parent))
                 self.target.add_lines(
                     version_id, parents, self.source.get_lines(version_id))
                 count = count + 1
@@ -2920,10 +2911,12 @@
                 # add a key, no parents
                 self._revision_id_graph[missing_version] = ()
                 pending.discard(missing_version) # don't look for it
-        # XXX: This should probably be a real exception, as it is a data
-        #      inconsistency
-        assert not self._ghosts.intersection(self._compression_children), \
-            "We cannot have nodes which have a compression parent of a ghost."
+        if self._ghosts.intersection(self._compression_children):
+            raise KnitCorrupt(
+                "We cannot have nodes which have a ghost compression parent:\n"
+                "ghosts: %r\n"
+                "compression children: %r"
+                % (self._ghosts, self._compression_children))
         # Cleanout anything that depends on a ghost so that we don't wait for
         # the ghost to show up
         for node in self._ghosts:
@@ -2957,7 +2950,6 @@
             if len(parent_ids) == 0:
                 # There are no parents for this node, so just add it
                 # TODO: This probably needs to be decoupled
-                assert compression_parent is None
                 fulltext_content, delta = self._knit.factory.parse_record(
                     rev_id, record, record_details, None)
                 fulltext = self._add_fulltext_content(rev_id, fulltext_content)
@@ -2974,7 +2966,9 @@
                  record_details) = self._all_build_details[rev_id]
                 if compression_parent is not None:
                     comp_children = self._compression_children[compression_parent]
-                    assert rev_id in comp_children
+                    if rev_id not in comp_children:
+                        raise AssertionError("%r not in compression children %r"
+                            % (rev_id, comp_children))
                     # If there is only 1 child, it is safe to reuse this
                     # content
                     reuse_content = (len(comp_children) == 1

=== modified file 'bzrlib/lazy_import.py'
--- bzrlib/lazy_import.py	2007-11-09 01:55:37 +0000
+++ bzrlib/lazy_import.py	2008-04-24 07:22:53 +0000
@@ -170,9 +170,8 @@
             from foo import bar, baz would get translated into 2 import
             requests. On for 'name=bar' and one for 'name=baz'
         """
-        if member is not None:
-            assert not children, \
-                'Cannot supply both a member and children'
+        if (member is not None) and children:
+            raise ValueError('Cannot supply both a member and children')
 
         object.__setattr__(self, '_import_replacer_children', children)
         object.__setattr__(self, '_member', member)
@@ -260,7 +259,9 @@
 
         :param import_str: The import string to process
         """
-        assert import_str.startswith('import ')
+        if not import_str.startswith('import '):
+            raise ValueError('bad import string %r'
+                % (import_str,))
         import_str = import_str[len('import '):]
 
         for path in import_str.split(','):
@@ -305,7 +306,8 @@
 
         :param from_str: The import string to process
         """
-        assert from_str.startswith('from ')
+        if not from_str.startswith('from '):
+            raise ValueError('bad from/import %r' % from_str)
         from_str = from_str[len('from '):]
 
         from_module, import_list = from_str.split(' import ')

=== modified file 'bzrlib/lazy_regex.py'
--- bzrlib/lazy_regex.py	2006-10-16 01:25:46 +0000
+++ bzrlib/lazy_regex.py	2008-04-24 07:22:53 +0000
@@ -101,6 +101,7 @@
 
 
 _real_re_compile = re.compile
-assert _real_re_compile is not lazy_compile, \
-    "re.compile has already been overridden as lazy_compile, but this would" \
-    " cause infinite recursion"
+if _real_re_compile is lazy_compile:
+    raise AssertionError(
+        "re.compile has already been overridden as lazy_compile, but this would" \
+        " cause infinite recursion")

=== modified file 'bzrlib/lock.py'
--- bzrlib/lock.py	2007-10-03 08:06:44 +0000
+++ bzrlib/lock.py	2008-04-24 07:22:53 +0000
@@ -187,7 +187,9 @@
 
             :return: A token which can be used to switch back to a read lock.
             """
-            assert self.filename not in _fcntl_WriteLock._open_locks
+            if self.filename in _fcntl_WriteLock._open_locks:
+                raise AssertionError('file already locked: %r'
+                    % (self.filename,))
             try:
                 wlock = _fcntl_TemporaryWriteLock(self)
             except errors.LockError:
@@ -213,7 +215,9 @@
                 # write lock.
                 raise errors.LockContention(self.filename)
 
-            assert self.filename not in _fcntl_WriteLock._open_locks
+            if self.filename in _fcntl_WriteLock._open_locks:
+                raise AssertionError('file already locked: %r'
+                    % (self.filename,))
 
             # See if we can open the file for writing. Another process might
             # have a read lock. We don't use self._open() because we don't want

=== modified file 'bzrlib/lockable_files.py'
--- bzrlib/lockable_files.py	2008-04-09 02:32:18 +0000
+++ bzrlib/lockable_files.py	2008-04-24 07:22:53 +0000
@@ -242,8 +242,8 @@
     def lock_read(self):
         # mutter("lock read: %s (%s)", self, self._lock_count)
         if self._lock_mode:
-            assert self._lock_mode in ('r', 'w'), \
-                   "invalid lock mode %r" % self._lock_mode
+            if self._lock_mode not in ('r', 'w'):
+                raise ValueError("invalid lock mode %r" % (self._lock_mode,))
             self._lock_count += 1
         else:
             self._lock.lock_read()

=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2007-10-03 08:06:44 +0000
+++ bzrlib/lockdir.py	2008-04-24 07:22:53 +0000
@@ -167,8 +167,6 @@
         :param path: Path to the lock within the base directory of the 
             transport.
         """
-        assert isinstance(transport, Transport), \
-            ("not a transport: %r" % transport)
         self.transport = transport
         self.path = path
         self._lock_held = False
@@ -417,8 +415,6 @@
         try:
             info = self._read_info_file(self._held_info_path)
             self._trace("peek -> held")
-            assert isinstance(info, dict), \
-                    "bad parse result %r" % info
             return info
         except NoSuchFile, e:
             self._trace("peek -> not held")

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2008-04-18 17:54:34 +0000
+++ bzrlib/log.py	2008-04-24 07:22:53 +0000
@@ -552,7 +552,6 @@
         if val[2] == _depth:
             zd_revisions.append([val])
         else:
-            assert val[2] > _depth
             zd_revisions[-1].append(val)
     for revisions in zd_revisions:
         if len(revisions) > 1:

=== modified file 'bzrlib/lru_cache.py'
--- bzrlib/lru_cache.py	2007-11-16 23:53:17 +0000
+++ bzrlib/lru_cache.py	2008-04-24 07:22:53 +0000
@@ -109,8 +109,9 @@
         self._queue = new_queue
         # All entries should be of the same size. There should be one entry in
         # queue for each entry in cache, and all refcounts should == 1
-        assert (len(self._queue) == len(self._cache) ==
-                len(self._refcount) == sum(self._refcount.itervalues()))
+        if not (len(self._queue) == len(self._cache) ==
+                len(self._refcount) == sum(self._refcount.itervalues())):
+            raise AssertionError()
 
     def _remove(self, key):
         """Remove an entry, making sure to maintain the invariants."""

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2008-03-25 04:00:51 +0000
+++ bzrlib/merge.py	2008-04-24 07:22:53 +0000
@@ -68,7 +68,6 @@
                  this_tree=None, pb=DummyProgress(), change_reporter=None,
                  recurse='down', revision_graph=None):
         object.__init__(self)
-        assert this_tree is not None, "this_tree is required"
         self.this_branch = this_branch
         self.this_basis = _mod_revision.ensure_null(
             this_branch.last_revision())
@@ -236,7 +235,6 @@
         self.ensure_revision_trees()
         def get_id(tree, file_id):
             revision_id = tree.inventory[file_id].revision
-            assert revision_id is not None
             return revision_id
         if self.this_rev_id is None:
             if self.this_basis_tree.get_file_sha1(file_id) != \
@@ -490,8 +488,9 @@
             merge.
         """
         object.__init__(self)
-        if interesting_files is not None:
-            assert interesting_ids is None
+        if interesting_files is not None and interesting_ids is not None:
+            raise ValueError(
+                'specify either interesting_ids or interesting_files')
         self.interesting_ids = interesting_ids
         self.interesting_files = interesting_files
         self.this_tree = working_tree
@@ -712,14 +711,13 @@
         if key_base == key_other:
             return "this"
         key_this = key(this_tree, file_id)
-        if key_this not in (key_base, key_other):
+        # "Ambiguous clean merge"
+        if key_this == key_other:
+            return "this"
+        elif key_this == key_base:
+            return "other"
+        else:
             return "conflict"
-        # "Ambiguous clean merge"
-        elif key_this == key_other:
-            return "this"
-        else:
-            assert key_this == key_base
-            return "other"
 
     def merge_names(self, file_id):
         def get_entry(tree):
@@ -969,7 +967,6 @@
         if winner == "this":
             executability = this_executable
         else:
-            assert winner == "other"
             if file_id in self.other_tree:
                 executability = other_executable
             elif file_id in self.this_tree:
@@ -1017,13 +1014,15 @@
         for trans_id, conflicts in name_conflicts.iteritems():
             try:
                 this_parent, other_parent = conflicts['parent conflict']
-                assert this_parent != other_parent
+                if this_parent == other_parent:
+                    raise AssertionError()
             except KeyError:
                 this_parent = other_parent = \
                     self.tt.final_file_id(self.tt.final_parent(trans_id))
             try:
                 this_name, other_name = conflicts['name conflict']
-                assert this_name != other_name
+                if this_name == other_name:
+                    raise AssertionError()
             except KeyError:
                 this_name = other_name = self.tt.final_name(trans_id)
             other_path = fp.get_path(trans_id)
@@ -1182,8 +1181,9 @@
     merger.interesting_ids = interesting_ids
     merger.ignore_zero = ignore_zero
     if interesting_files:
-        assert not interesting_ids, ('Only supply interesting_ids'
-                                     ' or interesting_files')
+        if interesting_ids:
+            raise ValueError('Only supply interesting_ids'
+                             ' or interesting_files')
         merger.interesting_files = interesting_files
     merger.show_base = show_base
     merger.reprocess = reprocess
@@ -1236,7 +1236,6 @@
         a_cur = ai + l
         b_cur = bi + l
         for text_a, text_b in zip(plain_a[ai:a_cur], plain_b[bi:b_cur]):
-            assert text_a == text_b
             yield "unchanged", text_a
 
 

=== modified file 'bzrlib/merge3.py'
--- bzrlib/merge3.py	2008-03-14 16:13:25 +0000
+++ bzrlib/merge3.py	2008-04-24 07:22:53 +0000
@@ -36,9 +36,6 @@
     >>> intersect((0, 9), (7, 15))
     (7, 9)
     """
-    assert ra[0] <= ra[1]
-    assert rb[0] <= rb[1]
-    
     sa = max(ra[0], rb[0])
     sb = min(ra[1], rb[1])
     if sa < sb:
@@ -222,20 +219,10 @@
         iz = ia = ib = 0
         
         for zmatch, zend, amatch, aend, bmatch, bend in self.find_sync_regions():
-            #print 'match base [%d:%d]' % (zmatch, zend)
-            
             matchlen = zend - zmatch
-            assert matchlen >= 0
-            assert matchlen == (aend - amatch)
-            assert matchlen == (bend - bmatch)
-            
             len_a = amatch - ia
             len_b = bmatch - ib
             len_base = zmatch - iz
-            assert len_a >= 0
-            assert len_b >= 0
-            assert len_base >= 0
-
             #print 'unmatched a=%d, b=%d' % (len_a, len_b)
 
             if len_a or len_b:
@@ -273,10 +260,6 @@
             # that's OK, we can just skip it.
 
             if matchlen > 0:
-                assert ia == amatch
-                assert ib == bmatch
-                assert iz == zmatch
-                
                 yield 'unchanged', zmatch, zend
                 iz = zend
                 ia = aend
@@ -386,28 +369,13 @@
                 intbase = i[0]
                 intend = i[1]
                 intlen = intend - intbase
-
-                # found a match of base[i[0], i[1]]; this may be less than
-                # the region that matches in either one
-                assert intlen <= alen
-                assert intlen <= blen
-                assert abase <= intbase
-                assert bbase <= intbase
-
                 asub = amatch + (intbase - abase)
                 bsub = bmatch + (intbase - bbase)
                 aend = asub + intlen
                 bend = bsub + intlen
-
-                assert self.base[intbase:intend] == self.a[asub:aend], \
-                       (self.base[intbase:intend], self.a[asub:aend])
-
-                assert self.base[intbase:intend] == self.b[bsub:bend]
-
                 sl.append((intbase, intend,
                            asub, aend,
                            bsub, bend))
-
             # advance whichever one ends first in the base text
             if (abase + alen) < (bbase + blen):
                 ia += 1

=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2008-03-07 18:21:28 +0000
+++ bzrlib/merge_directive.py	2008-04-24 07:22:53 +0000
@@ -273,7 +273,8 @@
         """
         _BaseMergeDirective.__init__(self, revision_id, testament_sha1, time,
             timezone, target_branch, patch, source_branch, message)
-        assert patch_type in (None, 'diff', 'bundle'), patch_type
+        if patch_type not in (None, 'diff', 'bundle'):
+            raise ValueError(patch_type)
         if patch_type != 'bundle' and source_branch is None:
             raise errors.NoMergeSource()
         if patch_type is not None and patch is None:

=== modified file 'bzrlib/multiparent.py'
--- bzrlib/multiparent.py	2008-04-09 00:34:54 +0000
+++ bzrlib/multiparent.py	2008-04-24 07:22:53 +0000
@@ -57,7 +57,6 @@
             yield version_id
             seen.add(version_id)
         cur = next
-    assert len(seen) == len(versions)
 
 
 class MultiParent(object):
@@ -195,7 +194,8 @@
             elif cur_line[0] == '\n':
                 hunks[-1].lines[-1] += '\n'
             else:
-                assert cur_line[0] == 'c', cur_line[0]
+                if not (cur_line[0] == 'c'):
+                    raise AssertionError(cur_line[0])
                 parent, parent_pos, child_pos, num_lines =\
                     [int(v) for v in cur_line.split(' ')[1:]]
                 hunks.append(ParentText(parent, parent_pos, child_pos,
@@ -370,7 +370,8 @@
         :param single_parent: If true, omit all but one parent text, (but
             retain parent metadata).
         """
-        assert no_cache or not verify
+        if not (no_cache or not verify):
+            raise ValueError()
         revisions = set(vf.versions())
         total = len(revisions)
         pb = ui.ui_factory.nested_progress_bar()
@@ -394,7 +395,8 @@
                         self.clear_cache()
                         vf.clear_cache()
                         if verify:
-                            assert lines == self.get_line_list([revision])[0]
+                            if not (lines == self.get_line_list([revision])[0]):
+                                raise AssertionError()
                             self.clear_cache()
                     pb.update('Importing revisions',
                               (total - len(revisions)) + len(added), total)

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2008-04-05 13:45:37 +0000
+++ bzrlib/mutabletree.py	2008-04-24 07:22:53 +0000
@@ -96,8 +96,12 @@
         TODO: Perhaps callback with the ids and paths as they're added.
         """
         if isinstance(files, basestring):
-            assert(ids is None or isinstance(ids, basestring))
-            assert(kinds is None or isinstance(kinds, basestring))
+            # XXX: Passing a single string is inconsistent and should be
+            # deprecated.
+            if not (ids is None or isinstance(ids, basestring)):
+                raise AssertionError()
+            if not (kinds is None or isinstance(kinds, basestring)):
+                raise AssertionError()
             files = [files]
             if ids is not None:
                 ids = [ids]
@@ -109,11 +113,12 @@
         if ids is None:
             ids = [None] * len(files)
         else:
-            assert(len(ids) == len(files))
+            if not (len(ids) == len(files)):
+                raise AssertionError()
         if kinds is None:
             kinds = [None] * len(files)
-        else:
-            assert(len(kinds) == len(files))
+        elif not len(kinds) == len(files):
+            raise AssertionError()
         for f in files:
             # generic constraint checks:
             if self.is_control_filename(f):
@@ -180,7 +185,9 @@
             revprops['branch-nick'] = self.branch.nick
         author = kwargs.pop('author', None)
         if author is not None:
-            assert 'author' not in revprops
+            if 'author' in revprops:
+                # XXX: maybe we should just accept one of them?
+                raise AssertionError('author property given twice')
             revprops['author'] = author
         # args for wt.commit start at message from the Commit.commit method,
         args = (message, ) + args
@@ -276,7 +283,6 @@
         # not in an inner loop; and we want to remove direct use of this,
         # so here as a reminder for now. RBC 20070703
         from bzrlib.inventory import InventoryEntry
-        assert isinstance(recurse, bool)
         if action is None:
             action = add.AddAction()
         

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2008-02-26 23:45:24 +0000
+++ bzrlib/option.py	2008-04-24 07:22:53 +0000
@@ -179,7 +179,8 @@
         self.type = type
         self._short_name = short_name
         if type is None:
-            assert argname is None
+            if argname:
+                raise ValueError('argname not valid for booleans')
         elif argname is None:
             argname = 'ARG'
         self.argname = argname

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2008-04-07 07:34:32 +0000
+++ bzrlib/osutils.py	2008-04-24 07:22:53 +0000
@@ -555,8 +555,10 @@
 
 
 def sha_file(f):
-    if getattr(f, 'tell', None) is not None:
-        assert f.tell() == 0
+    """Calculate the hexdigest of an open file.
+
+    The file cursor should be already at the start.
+    """
     s = sha.new()
     BUFSIZE = 128<<10
     while True:
@@ -750,8 +752,6 @@
 
 def splitpath(p):
     """Turn string into list of parts."""
-    assert isinstance(p, basestring)
-
     # split on either delimiter because people might use either on
     # Windows
     ps = re.split(r'[\\/]', p)
@@ -767,7 +767,6 @@
     return rps
 
 def joinpath(p):
-    assert isinstance(p, (list, tuple))
     for f in p:
         if (f == '..') or (f is None) or (f == ''):
             raise errors.BzrError("sorry, %r not allowed in path" % f)
@@ -867,9 +866,10 @@
     avoids that problem.
     """
 
-    assert len(base) >= MIN_ABS_PATHLENGTH, ('Length of base must be equal or'
-        ' exceed the platform minimum length (which is %d)' % 
-        MIN_ABS_PATHLENGTH)
+    if len(base) < MIN_ABS_PATHLENGTH:
+        # must have space for e.g. a drive letter
+        raise ValueError('%r is too short to calculate a relative path'
+            % (base,))
 
     rp = abspath(path)
 

=== modified file 'bzrlib/patches.py'
--- bzrlib/patches.py	2007-08-17 17:56:35 +0000
+++ bzrlib/patches.py	2008-04-24 07:22:53 +0000
@@ -220,7 +220,6 @@
             return self.shift_to_mod_lines(pos)
 
     def shift_to_mod_lines(self, pos):
-        assert (pos >= self.orig_pos-1 and pos <= self.orig_pos+self.orig_range)
         position = self.orig_pos-1
         shift = 0
         for line in self.lines:
@@ -355,7 +354,8 @@
     last_line = None
     for line in iter_lines:
         if line == NO_NL:
-            assert last_line.endswith('\n')
+            if not last_line.endswith('\n'):
+                raise AssertionError()
             last_line = last_line[:-1]
             line = None
         if last_line is not None:
@@ -415,7 +415,8 @@
                 if isinstance(hunk_line, ContextLine):
                     yield orig_line
                 else:
-                    assert isinstance(hunk_line, RemoveLine)
+                    if not isinstance(hunk_line, RemoveLine):
+                        raise AssertionError(hunk_line)
                 line_no += 1
     if orig_lines is not None:
         for line in orig_lines:

=== modified file 'bzrlib/plugins/launchpad/lp_registration.py'
--- bzrlib/plugins/launchpad/lp_registration.py	2008-03-03 17:13:31 +0000
+++ bzrlib/plugins/launchpad/lp_registration.py	2008-04-24 07:22:53 +0000
@@ -104,9 +104,12 @@
             # TODO: if there's no registrant email perhaps we should
             # just connect anonymously?
             scheme, hostinfo, path = urlsplit(self.service_url)[:3]
-            assert '@' not in hostinfo
-            assert self.registrant_email is not None
-            assert self.registrant_password is not None
+            if '@' in hostinfo:
+                raise AssertionError(hostinfo)
+            if self.registrant_email is None:
+                raise AssertionError()
+            if self.registrant_password is None:
+                raise AssertionError()
             # TODO: perhaps fully quote the password to make it very slightly
             # obscured
             # TODO: can we perhaps add extra Authorization headers
@@ -139,7 +142,6 @@
 
     def send_request(self, method_name, method_params, authenticated):
         proxy = self.get_proxy(authenticated)
-        assert method_name
         method = getattr(proxy, method_name)
         try:
             result = method(*method_params)
@@ -240,7 +242,6 @@
     _methodname = 'link_branch_to_bug'
 
     def __init__(self, branch_url, bug_id):
-        assert branch_url
         self.bug_id = bug_id
         self.branch_url = branch_url
 

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2008-01-25 11:06:32 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2008-04-24 07:22:53 +0000
@@ -92,13 +92,16 @@
         self.connected_host = host
         if self.expect_auth:
             auth_hdrs = [v for k,v in http_headers if k == 'Authorization']
-            assert len(auth_hdrs) == 1
+            if len(auth_hdrs):
+                raise AssertionError("multiple auth headers: %r"
+                    % (auth_hdrs,))
             authinfo = auth_hdrs[0]
             expected_auth = 'testuser@launchpad.net:testpassword'
             test.assertEquals(authinfo,
                     'Basic ' + base64.encodestring(expected_auth).strip())
         else:
-            assert not http_headers
+            if http_headers:
+                raise AssertionError()
         return InstrumentedXMLRPCConnection(test)
 
     def send_request(self, connection, handler_path, request_body):
@@ -115,8 +118,6 @@
 
     def send_content(self, conn, request_body):
         unpacked, method = xmlrpclib.loads(request_body)
-        assert None not in unpacked, \
-                "xmlrpc result %r shouldn't contain None" % (unpacked,)
         self.sent_params = unpacked
 
 

=== modified file 'bzrlib/progress.py'
--- bzrlib/progress.py	2008-04-16 14:44:53 +0000
+++ bzrlib/progress.py	2008-04-24 07:22:53 +0000
@@ -189,7 +189,6 @@
     def finished(self):
         """Return this bar to its progress stack."""
         self.clear()
-        assert self._stack is not None
         self._stack.return_pb(self)
 
     def note(self, fmt_string, *args, **kwargs):
@@ -531,8 +530,6 @@
     
     total_duration = float(elapsed) * float(total) / float(current)
 
-    assert total_duration >= elapsed
-
     if last_updates and len(last_updates) >= n_recent:
         avg = sum(last_updates) / float(len(last_updates))
         time_left = avg * (total - current)
@@ -559,5 +556,4 @@
             self.cur_phase = 0
         else:
             self.cur_phase += 1
-        assert self.cur_phase < self.total
         self.pb.update(self.message, self.cur_phase, self.total)

=== modified file 'bzrlib/reconcile.py'
--- bzrlib/reconcile.py	2008-03-26 21:42:35 +0000
+++ bzrlib/reconcile.py	2008-04-24 07:22:53 +0000
@@ -184,7 +184,9 @@
             parents = self._rev_graph[rev_id]
             # double check this really is in topological order.
             unavailable = [p for p in parents if p not in new_inventory_vf]
-            assert len(unavailable) == 0
+            if unavailable:
+                raise AssertionError('unavailable parents: %r'
+                    % unavailable)
             # this entry has all the non ghost parents in the inventory
             # file already.
             self._reweave_step('adding inventories')
@@ -203,7 +205,8 @@
             new_inventory_vf._save()
         # if this worked, the set of new_inventory_vf.names should equal
         # self.pending
-        assert set(new_inventory_vf.versions()) == self.pending
+        if not (set(new_inventory_vf.versions()) == self.pending):
+            raise AssertionError()
         self.pb.update('Writing weave')
         self.repo.control_weaves.copy(new_inventory_vf, 'inventory', self.repo.get_transaction())
         self.repo.control_weaves.delete('inventory.new', self.repo.get_transaction())
@@ -221,7 +224,6 @@
         # analyse revision id rev_id and put it in the stack.
         self._reweave_step('loading revisions')
         rev = self.repo.get_revision_reconcile(rev_id)
-        assert rev.revision_id == rev_id
         parents = []
         for parent in rev.parent_ids:
             if self._parent_is_available(parent):
@@ -340,7 +342,9 @@
             # double check this really is in topological order, ignoring existing ghosts.
             unavailable = [p for p in parents if p not in new_inventory_vf and
                 p in self.revisions]
-            assert len(unavailable) == 0
+            if unavailable:
+                raise AssertionError(
+                    'unavailable parents: %r' % (unavailable,))
             # this entry has all the non ghost parents in the inventory
             # file already.
             self._reweave_step('adding inventories')
@@ -350,7 +354,8 @@
 
         # if this worked, the set of new_inventory_vf.names should equal
         # self.pending
-        assert set(new_inventory_vf.versions()) == set(self.revisions.versions())
+        if not(set(new_inventory_vf.versions()) == set(self.revisions.versions())):
+            raise AssertionError()
         self.pb.update('Writing weave')
         self.repo.control_weaves.copy(new_inventory_vf, 'inventory', self.transaction)
         self.repo.control_weaves.delete('inventory.new', self.transaction)

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2008-04-10 16:41:50 +0000
+++ bzrlib/remote.py	2008-04-24 07:22:53 +0000
@@ -34,7 +34,10 @@
 from bzrlib.bzrdir import BzrDir, RemoteBzrDirFormat
 from bzrlib.config import BranchConfig, TreeConfig
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-from bzrlib.errors import NoSuchRevision
+from bzrlib.errors import (
+    NoSuchRevision,
+    SmartProtocolError,
+    )
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.pack import ContainerPushParser
 from bzrlib.smart import client, vfs
@@ -136,7 +139,8 @@
         return None, self.open_branch()
 
     def open_branch(self, _unsupported=False):
-        assert _unsupported == False, 'unsupported flag support not implemented yet.'
+        if _unsupported:
+            raise NotImplementedError('unsupported flag support not implemented yet.')
         reference_url = self.get_branch_reference()
         if reference_url is None:
             # branch at this location.
@@ -154,15 +158,17 @@
         except errors.UnknownSmartMethod:
             verb = 'BzrDir.find_repository'
             response = self._client.call(verb, path)
-        assert response[0] in ('ok', 'norepository'), \
-            'unexpected response code %s' % (response,)
         if response[0] == 'norepository':
             raise errors.NoRepositoryPresent(self)
+        elif response[0] != 'ok':
+            raise SmartProtocolError('unexpected response %r' 
+                % response)
         if verb == 'BzrDir.find_repository':
             # servers that don't support the V2 method don't support external
             # references either.
             response = response + ('no', )
-        assert len(response) == 5, 'incorrect response length %s' % (response,)
+        if not (len(response) == 5):
+            raise SmartProtocolError('incorrect response length %s' % (response,))
         if response[1] == '':
             format = RemoteRepositoryFormat()
             format.rich_root_data = (response[2] == 'yes')
@@ -226,12 +232,13 @@
     _matchingbzrdir = RemoteBzrDirFormat
 
     def initialize(self, a_bzrdir, shared=False):
-        assert isinstance(a_bzrdir, RemoteBzrDir), \
-            '%r is not a RemoteBzrDir' % (a_bzrdir,)
+        if not isinstance(a_bzrdir, RemoteBzrDir):
+            raise AssertionError('%r is not a RemoteBzrDir' % (a_bzrdir,))
         return a_bzrdir.create_repository(shared=shared)
     
     def open(self, a_bzrdir):
-        assert isinstance(a_bzrdir, RemoteBzrDir)
+        if not isinstance(a_bzrdir, RemoteBzrDir):
+            raise AssertionError('%r is not a RemoteBzrDir' % (a_bzrdir,))
         return a_bzrdir.open_repository()
 
     def get_format_description(self):
@@ -371,7 +378,6 @@
             return {}
 
         path = self.bzrdir._path_for_remote_call(self._client)
-        assert type(revision_id) is str
         response = self._client.call_expecting_body(
             'Repository.get_revision_graph', path, revision_id)
         if response[0][0] not in ['ok', 'nosuchrevision']:
@@ -390,7 +396,8 @@
             return revision_graph
         else:
             response_body = response[1].read_body_bytes()
-            assert response_body == ''
+            if response_body:
+                raise SmartProtocolError('unexpected response body')
             raise NoSuchRevision(self, revision_id)
 
     def has_revision(self, revision_id):
@@ -400,7 +407,8 @@
             return True
         path = self.bzrdir._path_for_remote_call(self._client)
         response = self._client.call('Repository.has_revision', path, revision_id)
-        assert response[0] in ('yes', 'no'), 'unexpected response code %s' % (response,)
+        if response[0] not in ('yes', 'no'):
+            raise SmartProtocolError('unexpected response code %s' % (response,))
         return response[0] == 'yes'
 
     def has_revisions(self, revision_ids):
@@ -439,8 +447,9 @@
             fmt_committers = 'yes'
         response = self._client.call_expecting_body(
             'Repository.gather_stats', path, fmt_revid, fmt_committers)
-        assert response[0][0] == 'ok', \
-            'unexpected response code %s' % (response[0],)
+        if response[0][0] != 'ok':
+            raise SmartProtocolError('unexpected response code %s'
+                % (response[0],))
 
         body = response[1].read_body_bytes()
         result = {}
@@ -483,7 +492,8 @@
         """See Repository.is_shared()."""
         path = self.bzrdir._path_for_remote_call(self._client)
         response = self._client.call('Repository.is_shared', path)
-        assert response[0] in ('yes', 'no'), 'unexpected response code %s' % (response,)
+        if response[0] not in ('yes', 'no'):
+            raise SmartProtocolError('unexpected response code %s' % (response,))
         return response[0] == 'yes'
 
     def is_write_locked(self):
@@ -559,7 +569,8 @@
         :param repository: The repository to fallback to for non-hpss
             implemented operations.
         """
-        assert not isinstance(repository, RemoteRepository)
+        if isinstance(repository, RemoteRepository):
+            raise AssertionError()
         self._real_repository = repository
         if self._lock_mode == 'w':
             # if we are already locked, the real repository must be able to
@@ -859,7 +870,8 @@
         body = self._serialise_search_recipe(recipe)
         path = self.bzrdir._path_for_remote_call(self._client)
         for key in keys:
-            assert type(key) is str
+            if not isinstance(key, str):
+                raise ValueError(key)
         verb = 'Repository.get_parent_map'
         args = (path,) + tuple(keys)
         try:
@@ -1153,8 +1165,9 @@
             path = self.bzrdir._path_for_remote_call(self._client)
             response = self._client.call_expecting_body(
                 'Branch.get_config_file', path)
-            assert response[0][0] == 'ok', \
-                'unexpected response code %s' % (response[0],)
+            if response[0][0] != 'ok':
+                raise SmartProtocolError(
+                    'unexpected response code %s' % (response[0],))
             return StringIO(response[1].read_body_bytes())
         else:
             # VFS fallback.
@@ -1174,11 +1187,9 @@
         return 'Remote BZR Branch'
 
     def open(self, a_bzrdir):
-        assert isinstance(a_bzrdir, RemoteBzrDir)
         return a_bzrdir.open_branch()
 
     def initialize(self, a_bzrdir):
-        assert isinstance(a_bzrdir, RemoteBzrDir)
         return a_bzrdir.create_branch()
 
     def supports_tags(self):
@@ -1245,7 +1256,9 @@
         Used before calls to self._real_branch.
         """
         if not self._real_branch:
-            assert vfs.vfs_enabled()
+            if not vfs.vfs_enabled():
+                raise AssertionError('smart server vfs must be enabled '
+                    'to use vfs implementation')
             self.bzrdir._ensure_real()
             self._real_branch = self.bzrdir._real_bzrdir.open_branch()
             # Give the remote repository the matching real repo.
@@ -1318,7 +1331,8 @@
         if not self._lock_mode:
             remote_tokens = self._remote_lock_write(token)
             self._lock_token, self._repo_lock_token = remote_tokens
-            assert self._lock_token, 'Remote server did not return a token!'
+            if not self._lock_token:
+                raise SmartProtocolError('Remote server did not return a token!')
             # TODO: We really, really, really don't want to call _ensure_real
             # here, but it's the easiest way to ensure coherency between the
             # state of the RemoteBranch and RemoteRepository objects and the
@@ -1383,7 +1397,8 @@
                 # Only write-locked branched need to make a remote method call
                 # to perfom the unlock.
                 return
-            assert self._lock_token, 'Locked, but no token!'
+            if not self._lock_token:
+                raise AssertionError('Locked, but no token!')
             branch_token = self._lock_token
             repo_token = self._repo_lock_token
             self._lock_token = None
@@ -1409,7 +1424,8 @@
         """See Branch.last_revision_info()."""
         path = self.bzrdir._path_for_remote_call(self._client)
         response = self._client.call('Branch.last_revision_info', path)
-        assert response[0] == 'ok', 'unexpected response code %s' % (response,)
+        if response[0] != 'ok':
+            raise SmartProtocolError('unexpected response code %s' % (response,))
         revno = int(response[1])
         last_revision = response[2]
         return (revno, last_revision)
@@ -1419,8 +1435,8 @@
         path = self.bzrdir._path_for_remote_call(self._client)
         response = self._client.call_expecting_body(
             'Branch.revision_history', path)
-        assert response[0][0] == 'ok', ('unexpected response code %s'
-                                        % (response[0],))
+        if response[0][0] != 'ok':
+            raise SmartProtocolError('unexpected response code %s' % (response,))
         result = response[1].read_body_bytes().split('\x00')
         if result == ['']:
             return []
@@ -1441,9 +1457,8 @@
             path, self._lock_token, self._repo_lock_token, rev_id)
         if response[0] == 'NoSuchRevision':
             raise NoSuchRevision(self, rev_id)
-        else:
-            assert response == ('ok',), (
-                'unexpected response code %r' % (response,))
+        elif response[0] != 'ok':
+            raise SmartProtocolError('unexpected response code %s' % (response,))
         self._cache_revision_history(rev_history)
 
     def get_parent(self):
@@ -1493,7 +1508,6 @@
 
     @needs_write_lock
     def set_last_revision_info(self, revno, revision_id):
-        assert type(revno) is int
         revision_id = ensure_null(revision_id)
         path = self.bzrdir._path_for_remote_call(self._client)
         try:

=== modified file 'bzrlib/repofmt/knitrepo.py'
--- bzrlib/repofmt/knitrepo.py	2008-04-04 00:06:58 +0000
+++ bzrlib/repofmt/knitrepo.py	2008-04-24 07:22:53 +0000
@@ -303,7 +303,8 @@
         :returns: an iterator yielding tuples of (revison-id, parents-in-index,
             parents-in-revision).
         """
-        assert self.is_locked()
+        if not self.is_locked():
+            raise AssertionError()
         vf = self._get_revision_vf()
         for index_version in vf.versions():
             parents_according_to_index = tuple(vf.get_parents_with_ghosts(
@@ -430,7 +431,6 @@
         """
         if not _found:
             format = RepositoryFormat.find_format(a_bzrdir)
-            assert format.__class__ ==  self.__class__
         if _override_transport is not None:
             repo_transport = _override_transport
         else:

=== modified file 'bzrlib/repofmt/pack_repo.py'
--- bzrlib/repofmt/pack_repo.py	2008-04-04 00:06:58 +0000
+++ bzrlib/repofmt/pack_repo.py	2008-04-24 07:22:53 +0000
@@ -198,8 +198,9 @@
             signature_index)
         self.name = name
         self.pack_transport = pack_transport
-        assert None not in (revision_index, inventory_index, text_index,
-            signature_index, name, pack_transport)
+        if None in (revision_index, inventory_index, text_index,
+                signature_index, name, pack_transport):
+            raise AssertionError()
 
     def __eq__(self, other):
         return self.__dict__ == other.__dict__
@@ -322,11 +323,12 @@
 
     def access_tuple(self):
         """Return a tuple (transport, name) for the pack content."""
-        assert self._state in ('open', 'finished')
         if self._state == 'finished':
             return Pack.access_tuple(self)
-        else:
+        elif self._state == 'open':
             return self.upload_transport, self.random_name
+        else:
+            raise AssertionError(self._state)
 
     def data_inserted(self):
         """True if data has been added to this pack."""
@@ -495,9 +497,10 @@
         :param index: An index from the pack parameter.
         :param pack: A Pack instance.
         """
-        assert self.add_callback is None, \
-            "%s already has a writable index through %s" % \
-            (self, self.add_callback)
+        if self.add_callback is not None:
+            raise AssertionError(
+                "%s already has a writable index through %s" % \
+                (self, self.add_callback))
         # allow writing: queue writes to a new index
         self.add_index(index, pack)
         # Updates the index to packs mapping as a side effect,
@@ -1149,7 +1152,8 @@
         
         :param pack: A Pack object.
         """
-        assert pack.name not in self._packs_by_name
+        if pack.name in self._packs_by_name:
+            raise AssertionError()
         self.packs.append(pack)
         self._packs_by_name[pack.name] = pack
         self.revision_index.add_index(pack.revision_index, pack)
@@ -2169,7 +2173,6 @@
         """
         if not _found:
             format = RepositoryFormat.find_format(a_bzrdir)
-            assert format.__class__ ==  self.__class__
         if _override_transport is not None:
             repo_transport = _override_transport
         else:

=== modified file 'bzrlib/repofmt/weaverepo.py'
--- bzrlib/repofmt/weaverepo.py	2008-04-10 06:19:49 +0000
+++ bzrlib/repofmt/weaverepo.py	2008-04-24 07:22:53 +0000
@@ -605,7 +605,6 @@
         """
         if not _found:
             format = RepositoryFormat.find_format(a_bzrdir)
-            assert format.__class__ ==  self.__class__
         if _override_transport is not None:
             repo_transport = _override_transport
         else:

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2008-04-16 14:54:19 +0000
+++ bzrlib/repository.py	2008-04-24 07:22:53 +0000
@@ -95,7 +95,6 @@
         if committer is None:
             self._committer = self._config.username()
         else:
-            assert isinstance(committer, basestring), type(committer)
             self._committer = committer
 
         self.new_inventory = Inventory(None)
@@ -328,8 +327,8 @@
             if kind != parent_entry.kind:
                 store = True
         if kind == 'file':
-            assert content_summary[2] is not None, \
-                "Files must not have executable = None"
+            if content_summary[2] is None:
+                raise ValueError("Files must not have executable = None")
             if not store:
                 if (# if the file length changed we have to store:
                     parent_entry.text_size != content_summary[1] or
@@ -501,12 +500,16 @@
         :returns: The validator(which is a sha1 digest, though what is sha'd is
             repository format specific) of the serialized inventory.
         """
-        assert self.is_in_write_group()
+        if not self.is_in_write_group():
+            raise AssertionError("%r not in write group" % (self,))
         _mod_revision.check_not_reserved_id(revision_id)
-        assert inv.revision_id is None or inv.revision_id == revision_id, \
-            "Mismatch between inventory revision" \
-            " id and insertion revid (%r, %r)" % (inv.revision_id, revision_id)
-        assert inv.root is not None
+        if not (inv.revision_id is None or inv.revision_id == revision_id):
+            raise AssertionError(
+                "Mismatch between inventory revision"
+                " id and insertion revid (%r, %r)"
+                % (inv.revision_id, revision_id))
+        if inv.root is None:
+            raise AssertionError()
         inv_lines = self._serialise_inventory_to_lines(inv)
         inv_vf = self.get_inventory_weave()
         return self._inventory_add_lines(inv_vf, revision_id, parents,
@@ -1092,10 +1095,6 @@
                 raise errors.InvalidRevisionId(revision_id=rev_id, branch=self)
         revs = self._revision_store.get_revisions(revision_ids,
                                                   self.get_transaction())
-        for rev in revs:
-            assert not isinstance(rev.revision_id, unicode)
-            for parent_id in rev.parent_ids:
-                assert not isinstance(parent_id, unicode)
         return revs
 
     @needs_read_lock
@@ -1501,8 +1500,9 @@
 
         :return: An iterator of inventories.
         """
-        assert None not in revision_ids
-        assert _mod_revision.NULL_REVISION not in revision_ids
+        if ((None in revision_ids)
+            or (_mod_revision.NULL_REVISION in revision_ids)):
+            raise ValueError('cannot get null revision inventory')
         return self._iter_inventories(revision_ids)
 
     def _iter_inventories(self, revision_ids):
@@ -1536,7 +1536,6 @@
     def get_inventory_xml(self, revision_id):
         """Get inventory XML as a file object."""
         try:
-            assert isinstance(revision_id, str), type(revision_id)
             iw = self.get_inventory_weave()
             return iw.get_text(revision_id)
         except IndexError:
@@ -2444,7 +2443,8 @@
         target_ids = set(self.target.all_revision_ids())
         if revision_id is not None:
             source_ids = self.source.get_ancestry(revision_id)
-            assert source_ids[0] is None
+            if source_ids[0] is not None:
+                raise AssertionError()
             source_ids.pop(0)
         else:
             source_ids = self.source.all_revision_ids()
@@ -2611,7 +2611,8 @@
         # - RBC 20060209
         if revision_id is not None:
             source_ids = self.source.get_ancestry(revision_id)
-            assert source_ids[0] is None
+            if source_ids[0] is not None:
+                raise AssertionError()
             source_ids.pop(0)
         else:
             source_ids = self.source._all_possible_ids()
@@ -2680,7 +2681,8 @@
         """See InterRepository.missing_revision_ids()."""
         if revision_id is not None:
             source_ids = self.source.get_ancestry(revision_id)
-            assert source_ids[0] is None
+            if source_ids[0] is not None:
+                raise AssertionError()
             source_ids.pop(0)
         else:
             source_ids = self.source.all_revision_ids()
@@ -2786,7 +2788,8 @@
             return self._walk_to_common_revisions([revision_id])
         elif revision_id is not None:
             source_ids = self.source.get_ancestry(revision_id)
-            assert source_ids[0] is None
+            if source_ids[0] is not None:
+                raise AssertionError()
             source_ids.pop(0)
         else:
             source_ids = self.source.all_revision_ids()
@@ -2953,8 +2956,9 @@
         # Is source's model compatible with target's model?
         source._ensure_real()
         real_source = source._real_repository
-        assert not isinstance(real_source, remote.RemoteRepository), (
-            "We don't support remote repos backed by remote repos yet.")
+        if isinstance(real_source, remote.RemoteRepository):
+            raise NotImplementedError(
+                "We don't support remote repos backed by remote repos yet.")
         return InterRepository._same_model(real_source, target)
 
     @needs_write_lock

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2008-03-26 21:42:35 +0000
+++ bzrlib/revision.py	2008-04-24 07:22:53 +0000
@@ -228,9 +228,6 @@
         for parent in parents:
             descendants[parent][node] = 1
         ancestors[node] = set(parents)
-
-    assert root not in descendants[root]
-    assert root not in ancestors[root]
     return root, ancestors, descendants
 
 
@@ -327,7 +324,6 @@
     @symbol_versioning.deprecated_method(symbol_versioning.one_three)
     def __init__(self, *args):
         object.__init__(self)
-        assert len(args) != 0
         self._revision_sources = args
 
     def revision_parents(self, revision_id):

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2008-03-29 21:16:20 +0000
+++ bzrlib/revisionspec.py	2008-04-24 07:22:53 +0000
@@ -160,10 +160,6 @@
 
         if spec is None:
             return RevisionSpec(None, _internal=True)
-
-        assert isinstance(spec, basestring), \
-            "You should only supply strings not %s" % (type(spec),)
-
         for spectype in SPEC_TYPES:
             if spec.startswith(spectype.prefix):
                 trace.mutter('Returning RevisionSpec %s for %s',

=== modified file 'bzrlib/revisiontree.py'
--- bzrlib/revisiontree.py	2008-04-09 00:34:54 +0000
+++ bzrlib/revisiontree.py	2008-04-24 07:22:53 +0000
@@ -162,7 +162,6 @@
         return entry.kind, entry.executable, None
 
     def _file_size(self, entry, stat_value):
-        assert entry.text_size is not None
         return entry.text_size
 
     def _get_ancestors(self, default_revision):

=== modified file 'bzrlib/rio.py'
--- bzrlib/rio.py	2007-10-16 16:02:01 +0000
+++ bzrlib/rio.py	2008-04-24 07:22:53 +0000
@@ -116,8 +116,8 @@
 
     def add(self, tag, value):
         """Append a name and value to the stanza."""
-        assert valid_tag(tag), \
-            ("invalid tag %r" % tag)
+        if not valid_tag(tag):
+            raise ValueError("invalid tag %r" % (tag,))
         if isinstance(value, str):
             value = unicode(value)
         elif isinstance(value, unicode):
@@ -165,8 +165,6 @@
             return []
         result = []
         for tag, value in self.items:
-            assert isinstance(tag, str), type(tag)
-            assert isinstance(value, unicode)
             if value == '':
                 result.append(tag + ': \n')
             elif '\n' in value:
@@ -235,7 +233,6 @@
         """
         d = {}
         for tag, value in self.items:
-            assert tag not in d
             d[tag] = value
         return d
          
@@ -291,7 +288,6 @@
             break       # end of file
         if line == '\n':
             break       # end of stanza
-        assert line.endswith('\n')
         real_l = line
         if line[0] == '\t': # continues previous value
             if tag is None:
@@ -306,8 +302,8 @@
                 raise ValueError('tag/value separator not found in line %r'
                                  % real_l)
             tag = str(line[:colon_index])
-            assert valid_tag(tag), \
-                    "invalid rio tag %r" % tag
+            if not valid_tag(tag):
+                raise ValueError("invalid rio tag %r" % (tag,))
             accum_value = line[colon_index+2:-1]
 
     if tag is not None: # add last tag-value
@@ -327,7 +323,8 @@
     :param max_width: The maximum number of characters per physical line.
     :return: a list of lines
     """
-    assert max_width > 6
+    if max_width <= 6:
+        raise ValueError(max_width)
     max_rio_width = max_width - 4
     lines = []
     for pline in stanza.to_lines():
@@ -373,9 +370,10 @@
     for line in line_iter:
         if line.startswith('# '):
             line = line[2:]
-        else:
-            assert line.startswith('#')
+        elif line.startswith('#'):
             line = line[1:]
+        else:
+            raise ValueError("bad line %r" % (line,))
         if last_line is not None and len(line) > 2:
             line = line[2:]
         line = re.sub('\r', '', line)

=== modified file 'bzrlib/smart/medium.py'
--- bzrlib/smart/medium.py	2008-04-14 08:03:35 +0000
+++ bzrlib/smart/medium.py	2008-04-24 07:22:53 +0000
@@ -77,17 +77,19 @@
 
         This sets the _push_back_buffer to the given bytes.
         """
-        assert self._push_back_buffer is None, (
-            "_push_back called when self._push_back_buffer is %r"
-            % (self._push_back_buffer,))
+        if self._push_back_buffer is not None:
+            raise AssertionError(
+                "_push_back called when self._push_back_buffer is %r"
+                % (self._push_back_buffer,))
         if bytes == '':
             return
         self._push_back_buffer = bytes
 
     def _get_push_back_buffer(self):
-        assert self._push_back_buffer != '', (
-            '%s._push_back_buffer should never be the empty string, '
-            'which can be confused with EOF' % (self,))
+        if self._push_back_buffer == '':
+            raise AssertionError(
+                '%s._push_back_buffer should never be the empty string, '
+                'which can be confused with EOF' % (self,))
         bytes = self._push_back_buffer
         self._push_back_buffer = None
         return bytes
@@ -663,7 +665,8 @@
         This clears the _current_request on self._medium to allow a new 
         request to be created.
         """
-        assert self._medium._current_request is self
+        if self._medium._current_request is not self:
+            raise AssertionError()
         self._medium._current_request = None
         
     def _finished_writing(self):

=== modified file 'bzrlib/smart/protocol.py'
--- bzrlib/smart/protocol.py	2008-04-07 10:34:57 +0000
+++ bzrlib/smart/protocol.py	2008-04-24 07:22:53 +0000
@@ -89,7 +89,8 @@
         
         :param bytes: must be a byte string
         """
-        assert isinstance(bytes, str)
+        if not isinstance(bytes, str):
+            raise ValueError(bytes)
         self.in_buffer += bytes
         if not self.has_dispatched:
             if '\n' not in self.in_buffer:
@@ -133,19 +134,21 @@
             self.request.accept_body(body_data)
             if self._body_decoder.finished_reading:
                 self.request.end_of_body()
-                assert self.request.finished_reading, \
-                    "no more body, request not finished"
+                if not self.request.finished_reading:
+                    raise AssertionError("no more body, request not finished")
             if self.request.response is not None:
                 self._send_response(self.request.response)
                 self.excess_buffer = self.in_buffer
                 self.in_buffer = ''
             else:
-                assert not self.request.finished_reading, \
-                    "no response and we have finished reading."
+                if self.request.finished_reading:
+                    raise AssertionError(
+                        "no response and we have finished reading.")
 
     def _send_response(self, response):
         """Send a smart server response down the output stream."""
-        assert not self._finished, 'response already sent'
+        if self._finished:
+            raise AssertionError('response already sent')
         args = response.args
         body = response.body
         self._finished = True
@@ -153,7 +156,8 @@
         self._write_success_or_failure_prefix(response)
         self._write_func(_encode_tuple(args))
         if body is not None:
-            assert isinstance(body, str), 'body must be a str'
+            if not isinstance(body, str):
+                raise ValueError(body)
             bytes = self._encode_bulk_data(body)
             self._write_func(bytes)
 
@@ -202,15 +206,18 @@
 
     def _send_response(self, response):
         """Send a smart server response down the output stream."""
-        assert not self._finished, 'response already sent'
+        if (self._finished):
+            raise AssertionError('response already sent')
         self._finished = True
         self._write_protocol_version()
         self._write_success_or_failure_prefix(response)
         self._write_func(_encode_tuple(response.args))
         if response.body is not None:
-            assert isinstance(response.body, str), 'body must be a str'
-            assert response.body_stream is None, (
-                'body_stream and body cannot both be set')
+            if not isinstance(response.body, str):
+                raise AssertionError('body must be a str')
+            if not (response.body_stream is None):
+                raise AssertionError(
+                    'body_stream and body cannot both be set')
             bytes = self._encode_bulk_data(response.body)
             self._write_func(bytes)
         elif response.body_stream is not None:

=== modified file 'bzrlib/smart/repository.py'
--- bzrlib/smart/repository.py	2008-03-28 07:37:07 +0000
+++ bzrlib/smart/repository.py	2008-04-24 07:22:53 +0000
@@ -389,7 +389,8 @@
             dirname = dirname.encode(sys.getfilesystemencoding())
             # python's tarball module includes the whole path by default so
             # override it
-            assert dirname.endswith('.bzr')
+            if not dirname.endswith('.bzr'):
+                raise ValueError(dirname)
             tarball.add(dirname, '.bzr') # recursive by default
         finally:
             tarball.close()

=== modified file 'bzrlib/smart/request.py'
--- bzrlib/smart/request.py	2008-04-08 06:38:34 +0000
+++ bzrlib/smart/request.py	2008-04-24 07:22:53 +0000
@@ -116,7 +116,8 @@
         if client_path.startswith(self._root_client_path):
             path = client_path[len(self._root_client_path):]
             relpath = urlutils.joinpath('/', path)
-            assert relpath.startswith('/')
+            if not relpath.startswith('/'):
+                raise ValueError(relpath)
             return '.' + relpath
         else:
             raise errors.PathNotChild(client_path, self._root_client_path)

=== modified file 'bzrlib/smart/server.py'
--- bzrlib/smart/server.py	2008-04-21 01:07:17 +0000
+++ bzrlib/smart/server.py	2008-04-24 07:22:53 +0000
@@ -235,7 +235,8 @@
             `bzr://127.0.0.1:nnnn/`.  Default value is `extra`, so that tests
             by default will fail unless they do the necessary path translation.
         """
-        assert client_path_extra.startswith('/')
+        if not client_path_extra.startswith('/'):
+            raise ValueError(client_path_extra)
         from bzrlib.transport.chroot import ChrootServer
         if backing_transport_server is None:
             from bzrlib.transport.local import LocalURLServer
@@ -254,7 +255,6 @@
 
     def get_url(self):
         url = super(SmartTCPServer_for_testing, self).get_url()
-        assert url.endswith('/')
         return url[:-1] + self.client_path_extra
 
     def get_bogus_url(self):
@@ -269,4 +269,3 @@
         """Get a backing transport from a server we are decorating."""
         url = 'readonly+' + backing_transport_server.get_url()
         return transport.get_transport(url)
-

=== modified file 'bzrlib/status.py'
--- bzrlib/status.py	2008-04-03 02:22:55 +0000
+++ bzrlib/status.py	2008-04-24 07:22:53 +0000
@@ -180,8 +180,8 @@
             to_file.write(line_log(m_revision, width - len(prefix)))
             to_file.write('\n')
             inner_merges = branch.repository.get_ancestry(merge)
-            assert inner_merges[0] is None
-            inner_merges.pop(0)
+            if inner_merges.pop(0) != None:
+                raise AssertionError()
             inner_merges.reverse()
             for mmerge in inner_merges:
                 if mmerge in ignore:

=== modified file 'bzrlib/store/__init__.py'
--- bzrlib/store/__init__.py	2007-09-25 08:14:12 +0000
+++ bzrlib/store/__init__.py	2008-04-24 07:22:53 +0000
@@ -145,7 +145,6 @@
                     failed.add(fileid)
                 else:
                     raise
-        assert count == len(ids)
         if pb:
             pb.clear()
         return count, failed
@@ -244,7 +243,6 @@
     def __init__(self, a_transport, prefixed=False, compressed=False,
                  dir_mode=None, file_mode=None,
                  escaped=False):
-        assert isinstance(a_transport, Transport)
         super(TransportStore, self).__init__()
         self._transport = a_transport
         self._prefixed = prefixed

=== modified file 'bzrlib/store/revision/knit.py'
--- bzrlib/store/revision/knit.py	2008-04-04 00:06:58 +0000
+++ bzrlib/store/revision/knit.py	2008-04-24 07:22:53 +0000
@@ -90,7 +90,6 @@
         try:
             for text, revision_id in zip(texts, revision_ids):
                 r = self._serializer.read_revision_from_string(text)
-                assert r.revision_id == revision_id
                 revisions.append(r)
         except SyntaxError, e:
             raise errors.BzrError('failed to unpack revision_xml for %s: %s' %

=== modified file 'bzrlib/store/revision/text.py'
--- bzrlib/store/revision/text.py	2007-09-25 08:14:12 +0000
+++ bzrlib/store/revision/text.py	2008-04-24 07:22:53 +0000
@@ -78,7 +78,6 @@
         """See RevisionStore.all_revision_ids()."""
         # for TextRevisionStores, this is only functional
         # on listable transports.
-        assert self.text_store.listable()
         result_graph = {}
         for rev_id in self.text_store:
             rev = self.get_revision(rev_id, transaction)
@@ -102,7 +101,6 @@
                                    [revision_id,
                                    str(e)])
             xml_file.close()
-            assert r.revision_id == revision_id
             revisions.append(r)
         return revisions
 

=== modified file 'bzrlib/store/versioned/__init__.py'
--- bzrlib/store/versioned/__init__.py	2008-04-08 00:57:07 +0000
+++ bzrlib/store/versioned/__init__.py	2008-04-24 07:22:53 +0000
@@ -214,7 +214,6 @@
         :param from_transaction: required current transaction in from_store.
         """
         from bzrlib.transactions import PassThroughTransaction
-        assert isinstance(from_store, WeaveStore)
         if from_transaction is None:
             warn("WeaveStore.copy_multi without a from_transaction parameter "
                  "is deprecated. Please provide a from_transaction.",

=== modified file 'bzrlib/testament.py'
--- bzrlib/testament.py	2007-02-18 00:22:24 +0000
+++ bzrlib/testament.py	2008-04-24 07:22:53 +0000
@@ -106,8 +106,10 @@
         self.parent_ids = rev.parent_ids[:]
         self.inventory = inventory
         self.revprops = copy(rev.properties)
-        assert not contains_whitespace(self.revision_id)
-        assert not contains_linebreaks(self.committer)
+        if contains_whitespace(self.revision_id):
+            raise ValueError(self.revision_id)
+        if contains_linebreaks(self.committer):
+            raise ValueError(self.committer)
 
     def as_text_lines(self):
         """Yield text form as a sequence of lines.
@@ -125,7 +127,8 @@
         # inventory length contains the root, which is not shown here
         a('parents:\n')
         for parent_id in sorted(self.parent_ids):
-            assert not contains_whitespace(parent_id)
+            if contains_whitespace(parent_id):
+                raise ValueError(parent_id)
             a('  %s\n' % parent_id)
         a('message:\n')
         for l in self.message.splitlines():
@@ -134,10 +137,6 @@
         for path, ie in self._get_entries():
             a(self._entry_to_line(path, ie))
         r.extend(self._revprops_to_lines())
-        if __debug__:
-            for l in r:
-                assert isinstance(l, basestring), \
-                    '%r of type %s is not a plain string' % (l, type(l))
         return [line.encode('utf-8') for line in r]
 
     def _get_entries(self):
@@ -146,22 +145,25 @@
         return entries
 
     def _escape_path(self, path):
-        assert not contains_linebreaks(path)
+        if contains_linebreaks(path):
+            raise ValueError(path)
         return unicode(path.replace('\\', '/').replace(' ', '\ '))
 
     def _entry_to_line(self, path, ie):
         """Turn an inventory entry into a testament line"""
-        assert not contains_whitespace(ie.file_id)
-
+        if contains_whitespace(ie.file_id):
+            raise ValueError(ie.file_id)
         content = ''
         content_spacer=''
         if ie.kind == 'file':
             # TODO: avoid switching on kind
-            assert ie.text_sha1
+            if not ie.text_sha1:
+                raise AssertionError()
             content = ie.text_sha1
             content_spacer = ' '
         elif ie.kind == 'symlink':
-            assert ie.symlink_target
+            if not ie.symlink_target:
+                raise AssertionError()
             content = self._escape_path(ie.symlink_target)
             content_spacer = ' '
 
@@ -186,8 +188,8 @@
             return []
         r = ['properties:\n']
         for name, value in sorted(self.revprops.items()):
-            assert isinstance(name, str)
-            assert not contains_whitespace(name)
+            if contains_whitespace(name):
+                raise ValueError(name)
             r.append('  %s:\n' % name)
             for line in value.splitlines():
                 r.append(u'    %s\n' % line)
@@ -223,7 +225,8 @@
         return self.inventory.iter_entries()
 
     def _escape_path(self, path):
-        assert not contains_linebreaks(path)
+        if contains_linebreaks(path):
+            raise ValueError(path)
         if path == '':
             path = '.'
         return unicode(path.replace('\\', '/').replace(' ', '\ '))

=== modified file 'bzrlib/tests/ftp_server.py'
--- bzrlib/tests/ftp_server.py	2007-11-25 14:34:44 +0000
+++ bzrlib/tests/ftp_server.py	2008-04-24 07:22:53 +0000
@@ -201,9 +201,9 @@
 
     def setUp(self, vfs_server=None):
         from bzrlib.transport.local import LocalURLServer
-        assert vfs_server is None or isinstance(vfs_server, LocalURLServer), \
-            "FTPServer currently assumes local transport, got %s" % vfs_server
-
+        if not (vfs_server is None or isinstance(vfs_server, LocalURLServer)):
+            raise AssertionError(
+                "FTPServer currently assumes local transport, got %s" % vfs_server)
         self._root = os.getcwdu()
         self._ftp_server = ftp_server(
             authorizer=test_authorizer(root=self._root),

=== modified file 'bzrlib/tests/http_server.py'
--- bzrlib/tests/http_server.py	2008-01-03 08:44:12 +0000
+++ bzrlib/tests/http_server.py	2008-04-24 07:22:53 +0000
@@ -496,10 +496,11 @@
         """
         # XXX: TODO: make the server back onto vfs_server rather than local
         # disk.
-        assert backing_transport_server is None or \
-            isinstance(backing_transport_server, local.LocalURLServer), \
-            "HTTPServer currently assumes local transport, got %s" % \
-            backing_transport_server
+        if not (backing_transport_server is None or \
+                isinstance(backing_transport_server, local.LocalURLServer)):
+            raise AssertionError(
+                "HTTPServer currently assumes local transport, got %s" % \
+                backing_transport_server)
         self._home_dir = os.getcwdu()
         self._local_path_parts = self._home_dir.split(os.path.sep)
         self._http_base_url = None

=== modified file 'bzrlib/tests/http_utils.py'
--- bzrlib/tests/http_utils.py	2007-12-28 15:33:47 +0000
+++ bzrlib/tests/http_utils.py	2008-04-24 07:22:53 +0000
@@ -25,8 +25,8 @@
 import urllib2
 import urlparse
 
-
 from bzrlib import (
+    errors,
     tests,
     transport,
     )
@@ -70,8 +70,9 @@
         # feeding the bytes in the http request to the smart_protocol_request,
         # but for now it's simpler to just feed the bytes directly.
         smart_protocol_request.accept_bytes(self.rfile.read(data_length))
-        assert smart_protocol_request.next_read_size() == 0, (
-            "not finished reading, but all data sent to protocol.")
+        if not (smart_protocol_request.next_read_size() == 0):
+            raise errors.SmartProtocolError(
+                "not finished reading, but all data sent to protocol.")
         self.send_header("Content-Length", str(len(out_buffer.getvalue())))
         self.end_headers()
         self.wfile.write(out_buffer.getvalue())

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2008-04-10 04:22:38 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2008-04-24 07:22:53 +0000
@@ -323,7 +323,7 @@
         repo = tree.branch.repository
         revision_ids = ['a-rev', 'b-rev', 'c-rev']
         revisions = repo.get_revisions(revision_ids)
-        assert len(revisions) == 3, repr(revisions)
+        self.assertEqual(len(revisions), 3)
         zipped = zip(revisions, revision_ids)
         self.assertEqual(len(zipped), 3)
         for revision, revision_id in zipped:
@@ -911,9 +911,9 @@
         self.addCleanup(repository.unlock)
         trees1 = list(repository.revision_trees(revision_ids))
         trees2 = [repository.revision_tree(t) for t in revision_ids]
-        assert len(trees1) == len(trees2)
+        self.assertEqual(len(trees1), len(trees2))
         for tree1, tree2 in zip(trees1, trees2):
-            assert not tree2.changes_from(tree1).has_changed()
+            self.assertFalse(tree2.changes_from(tree1).has_changed())
 
     def test_get_deltas_for_revisions(self):
         repository = self.bzrdir.open_repository()
@@ -924,7 +924,7 @@
         deltas1 = list(repository.get_deltas_for_revisions(revisions))
         deltas2 = [repository.get_revision_delta(r.revision_id) for r in
                    revisions]
-        assert deltas1 == deltas2
+        self.assertEqual(deltas1, deltas2)
 
     def test_all_revision_ids(self):
         # all_revision_ids -> all revisions

=== modified file 'bzrlib/tests/repository_implementations/test_revision.py'
--- bzrlib/tests/repository_implementations/test_revision.py	2006-08-15 17:01:22 +0000
+++ bzrlib/tests/repository_implementations/test_revision.py	2008-04-24 07:22:53 +0000
@@ -75,7 +75,7 @@
                                'unicode':'\xb5',
                                'multiline':'foo\nbar\n\n'
                               })
-        assert len(tree1.branch.revision_history()) > 0
+        self.assertTrue(len(tree1.branch.revision_history()) > 0)
         rev_a = tree1.branch.repository.get_revision(
                             tree1.branch.last_revision())
 

=== modified file 'bzrlib/tests/stub_sftp.py'
--- bzrlib/tests/stub_sftp.py	2006-09-08 18:52:17 +0000
+++ bzrlib/tests/stub_sftp.py	2008-04-24 07:22:53 +0000
@@ -71,9 +71,10 @@
         if home is None:
             self.home = ''
         else:
-            assert home.startswith(self.root), \
-                    "home must be a subdirectory of root (%s vs %s)" \
-                    % (home, root)
+            if not home.startswith(self.root):
+                raise AssertionError(
+                    "home must be a subdirectory of root (%s vs %s)"
+                    % (home, root))
             self.home = home[len(self.root):]
         if self.home.startswith('/'):
             self.home = self.home[1:]

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2008-03-26 03:06:52 +0000
+++ bzrlib/tests/test_bundle.py	2008-04-24 07:22:53 +0000
@@ -169,14 +169,14 @@
         self.assertEqual(btree.path2id("grandparent/parent"), "b")
         self.assertEqual(btree.path2id("grandparent/parent/file"), "c")
 
-        assert btree.path2id("grandparent2") is None
-        assert btree.path2id("grandparent2/parent") is None
-        assert btree.path2id("grandparent2/parent/file") is None
+        self.assertTrue(btree.path2id("grandparent2") is None)
+        self.assertTrue(btree.path2id("grandparent2/parent") is None)
+        self.assertTrue(btree.path2id("grandparent2/parent/file") is None)
 
         btree.note_rename("grandparent", "grandparent2")
-        assert btree.old_path("grandparent") is None
-        assert btree.old_path("grandparent/parent") is None
-        assert btree.old_path("grandparent/parent/file") is None
+        self.assertTrue(btree.old_path("grandparent") is None)
+        self.assertTrue(btree.old_path("grandparent/parent") is None)
+        self.assertTrue(btree.old_path("grandparent/parent/file") is None)
 
         self.assertEqual(btree.id2path("a"), "grandparent2")
         self.assertEqual(btree.id2path("b"), "grandparent2/parent")
@@ -186,9 +186,9 @@
         self.assertEqual(btree.path2id("grandparent2/parent"), "b")
         self.assertEqual(btree.path2id("grandparent2/parent/file"), "c")
 
-        assert btree.path2id("grandparent") is None
-        assert btree.path2id("grandparent/parent") is None
-        assert btree.path2id("grandparent/parent/file") is None
+        self.assertTrue(btree.path2id("grandparent") is None)
+        self.assertTrue(btree.path2id("grandparent/parent") is None)
+        self.assertTrue(btree.path2id("grandparent/parent/file") is None)
 
         btree.note_rename("grandparent/parent", "grandparent2/parent2")
         self.assertEqual(btree.id2path("a"), "grandparent2")
@@ -199,8 +199,8 @@
         self.assertEqual(btree.path2id("grandparent2/parent2"), "b")
         self.assertEqual(btree.path2id("grandparent2/parent2/file"), "c")
 
-        assert btree.path2id("grandparent2/parent") is None
-        assert btree.path2id("grandparent2/parent/file") is None
+        self.assertTrue(btree.path2id("grandparent2/parent") is None)
+        self.assertTrue(btree.path2id("grandparent2/parent/file") is None)
 
         btree.note_rename("grandparent/parent/file", 
                           "grandparent2/parent2/file2")
@@ -212,7 +212,7 @@
         self.assertEqual(btree.path2id("grandparent2/parent2"), "b")
         self.assertEqual(btree.path2id("grandparent2/parent2/file2"), "c")
 
-        assert btree.path2id("grandparent2/parent2/file") is None
+        self.assertTrue(btree.path2id("grandparent2/parent2/file") is None)
 
     def test_moves(self):
         """Ensure that file moves have the proper effect on children"""
@@ -221,7 +221,7 @@
                           "grandparent/alt_parent/file")
         self.assertEqual(btree.id2path("c"), "grandparent/alt_parent/file")
         self.assertEqual(btree.path2id("grandparent/alt_parent/file"), "c")
-        assert btree.path2id("grandparent/parent/file") is None
+        self.assertTrue(btree.path2id("grandparent/parent/file") is None)
 
     def unified_diff(self, old, new):
         out = StringIO()
@@ -233,8 +233,8 @@
         btree = self.make_tree_1()[0]
         btree.note_rename("grandparent/parent/file", 
                           "grandparent/alt_parent/file")
-        assert btree.id2path("e") is None
-        assert btree.path2id("grandparent/parent/file") is None
+        self.assertTrue(btree.id2path("e") is None)
+        self.assertTrue(btree.path2id("grandparent/parent/file") is None)
         btree.note_id("e", "grandparent/parent/file")
         return btree
 
@@ -298,8 +298,8 @@
         btree = self.make_tree_1()[0]
         self.assertEqual(btree.get_file("c").read(), "Hello\n")
         btree.note_deletion("grandparent/parent/file")
-        assert btree.id2path("c") is None
-        assert btree.path2id("grandparent/parent/file") is None
+        self.assertTrue(btree.id2path("c") is None)
+        self.assertTrue(btree.path2id("grandparent/parent/file") is None)
 
     def sorted_ids(self, tree):
         ids = list(tree)
@@ -464,8 +464,7 @@
         ancestors = write_bundle(self.b1.repository, rev_id, 'null:', s,
                                  format=self.format)
         s.seek(0)
-        assert isinstance(s.getvalue(), str), (
-            "Bundle isn't a bytestring:\n %s..." % repr(s.getvalue())[:40])
+        self.assertIsInstance(s.getvalue(), str)
         install_bundle(tree.branch.repository, read_bundle(s))
         for ancestor in ancestors:
             old = self.b1.repository.revision_tree(ancestor)

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2007-12-25 04:17:50 +0000
+++ bzrlib/tests/test_conflicts.py	2008-04-24 07:22:53 +0000
@@ -85,7 +85,7 @@
         restore('hello.sploo')
         self.assertEqual(len(tree.conflicts()), 0)
         self.assertFileEqual('hello world2', 'hello')
-        assert not os.path.lexists('hello.sploo')
+        self.assertFalse(os.path.lexists('hello.sploo'))
         self.assertRaises(NotConflicted, restore, 'hello')
         self.assertRaises(NotConflicted, restore, 'hello.sploo')
 

=== modified file 'bzrlib/tests/test_dirstate.py'
--- bzrlib/tests/test_dirstate.py	2008-02-13 01:35:27 +0000
+++ bzrlib/tests/test_dirstate.py	2008-04-24 07:22:53 +0000
@@ -162,7 +162,7 @@
         """
         # The state should already be write locked, since we just had to do
         # some operation to get here.
-        assert state._lock_token is not None
+        self.assertTrue(state._lock_token is not None)
         try:
             self.assertEqual(expected_result[0],  state.get_parent_ids())
             # there should be no ghosts in this tree.
@@ -2054,7 +2054,7 @@
         # the end it would still be fairly arbitrary, and we don't want the
         # extra overhead if we can avoid it. So sort everything to make sure
         # equality is true
-        assert len(map_keys) == len(paths)
+        self.assertEqual(len(map_keys), len(paths))
         expected = {}
         for path, keys in zip(paths, map_keys):
             if keys is None:
@@ -2079,8 +2079,7 @@
         :param paths: A list of directories
         """
         result = state._bisect_dirblocks(paths)
-        assert len(map_keys) == len(paths)
-
+        self.assertEqual(len(map_keys), len(paths))
         expected = {}
         for path, keys in zip(paths, map_keys):
             if keys is None:

=== modified file 'bzrlib/tests/test_merge_core.py'
--- bzrlib/tests/test_merge_core.py	2007-11-29 18:58:23 +0000
+++ bzrlib/tests/test_merge_core.py	2008-04-24 07:22:53 +0000
@@ -64,7 +64,8 @@
 
     def get_cset_path(self, parent, name):
         if name is None:
-            assert (parent is None)
+            if parent is not None:
+                raise AssertionError()
             return None
         return pathjoin(self.cset.entries[parent].path, name)
 
@@ -90,7 +91,8 @@
             tt.apply()
             wt.commit('branch commit')
             wt.flush()
-            assert len(wt.branch.revision_history()) == 2
+            if len(wt.branch.revision_history()) != 2:
+                raise AssertionError()
         self.this.branch.fetch(self.other.branch)
         other_basis = self.other.branch.basis_tree()
         merger = merge_type(self.this, self.this, self.base, other_basis, 

=== modified file 'bzrlib/tests/test_merge_directive.py'
--- bzrlib/tests/test_merge_directive.py	2008-03-07 18:17:13 +0000
+++ bzrlib/tests/test_merge_directive.py	2008-04-24 07:22:53 +0000
@@ -620,7 +620,7 @@
         public_branch=None, message=None, base_revision_id=None):
         include_patch = (patch_type in ('bundle', 'diff'))
         include_bundle = (patch_type == 'bundle')
-        assert patch_type in ('bundle', 'diff', None)
+        self.assertTrue(patch_type in ('bundle', 'diff', None))
         return merge_directive.MergeDirective2.from_objects(
             repository, revision_id, time, timezone, target_branch,
             include_patch, include_bundle, local_target_branch, public_branch,

=== modified file 'bzrlib/tests/test_patches.py'
--- bzrlib/tests/test_patches.py	2007-08-17 13:47:21 +0000
+++ bzrlib/tests/test_patches.py	2008-04-24 07:22:53 +0000
@@ -35,6 +35,9 @@
                             parse_patches)
 
 
+# XXX: Is there a good reason this uses unittest's test case rather than the
+# bzrlib one?
+
 class PatchesTester(unittest.TestCase):
     def datafile(self, filename):
         data_path = os.path.join(os.path.dirname(__file__), 
@@ -45,8 +48,8 @@
         """Parse a valid patch header"""
         lines = "--- orig/commands.py\n+++ mod/dommands.py\n".split('\n')
         (orig, mod) = get_patch_names(lines.__iter__())
-        assert(orig == "orig/commands.py")
-        assert(mod == "mod/dommands.py")
+        self.assertEqual(orig, "orig/commands.py")
+        self.assertEqual(mod, "mod/dommands.py")
 
     def testInvalidPatchHeader(self):
         """Parse an invalid patch header"""
@@ -58,21 +61,21 @@
         """Parse a valid hunk header"""
         header = "@@ -34,11 +50,6 @@\n"
         hunk = hunk_from_header(header);
-        assert (hunk.orig_pos == 34)
-        assert (hunk.orig_range == 11)
-        assert (hunk.mod_pos == 50)
-        assert (hunk.mod_range == 6)
-        assert (str(hunk) == header)
+        self.assertEqual(hunk.orig_pos, 34)
+        self.assertEqual(hunk.orig_range, 11)
+        self.assertEqual(hunk.mod_pos, 50)
+        self.assertEqual(hunk.mod_range, 6)
+        self.assertEqual(str(hunk), header)
 
     def testValidHunkHeader2(self):
         """Parse a tricky, valid hunk header"""
         header = "@@ -1 +0,0 @@\n"
         hunk = hunk_from_header(header);
-        assert (hunk.orig_pos == 1)
-        assert (hunk.orig_range == 1)
-        assert (hunk.mod_pos == 0)
-        assert (hunk.mod_range == 0)
-        assert (str(hunk) == header)
+        self.assertEqual(hunk.orig_pos, 1)
+        self.assertEqual(hunk.orig_range, 1)
+        self.assertEqual(hunk.mod_pos, 0)
+        self.assertEqual(hunk.mod_range, 0)
+        self.assertEqual(str(hunk), header)
 
     def testPDiff(self):
         """Parse a hunk header produced by diff -p"""
@@ -160,7 +163,7 @@
                     if line.contents != next:
                         sys.stdout.write(" orig:%spatch:%s" % (next,
                                          line.contents))
-                    assert(line.contents == next)
+                    self.assertEqual(line.contents, next)
         self.assertRaises(StopIteration, rem_iter.next)
 
     def testPatching(self):
@@ -188,7 +191,7 @@
     def testFirstLineRenumber(self):
         """Make sure we handle lines at the beginning of the hunk"""
         patch = parse_patch(self.datafile("insert_top.patch"))
-        assert (patch.pos_in_mod(0)==1)
+        self.assertEqual(patch.pos_in_mod(0), 1)
 
     def testParsePatches(self):
         """Make sure file names can be extracted from tricky unified diffs"""
@@ -224,7 +227,7 @@
         patch_files = []
         for patch in patches:
             patch_files.append((patch.oldname, patch.newname))
-        assert (patch_files == filenames)
+        self.assertEqual(patch_files, filenames)
             
 def test():
     patchesTestSuite = unittest.makeSuite(PatchesTester,'test')

=== modified file 'bzrlib/tests/test_permissions.py'
--- bzrlib/tests/test_permissions.py	2007-06-06 14:26:08 +0000
+++ bzrlib/tests/test_permissions.py	2008-04-24 07:22:53 +0000
@@ -47,7 +47,6 @@
 
 def chmod_r(base, file_mode, dir_mode):
     """Recursively chmod from a base directory"""
-    assert os.path.isdir(base)
     os.chmod(base, dir_mode)
     for root, dirs, files in os.walk(base):
         for d in dirs:
@@ -67,7 +66,6 @@
     :param dir_mode: The mode for all directories
     :param include_base: If false, only check the subdirectories
     """
-    assert os.path.isdir(base)
     t = get_transport(".")
     if include_base:
         test.assertTransportMode(t, base, dir_mode)

=== modified file 'bzrlib/tests/test_source.py'
--- bzrlib/tests/test_source.py	2008-04-23 01:28:37 +0000
+++ bzrlib/tests/test_source.py	2008-04-24 07:22:53 +0000
@@ -158,7 +158,7 @@
 
     def is_license_exception(self, fname):
         """Certain files are allowed to be different"""
-        if not self.is_our_code(self, fname):
+        if not self.is_our_code(fname):
             return True
         for exc in LICENSE_EXCEPTIONS:
             if fname.endswith(exc):

=== modified file 'bzrlib/tests/test_subsume.py'
--- bzrlib/tests/test_subsume.py	2008-04-04 00:06:58 +0000
+++ bzrlib/tests/test_subsume.py	2008-04-24 07:22:53 +0000
@@ -59,7 +59,7 @@
 
     def test_subsume_tree(self):
         base_tree, sub_tree = self.make_trees()
-        assert base_tree.get_root_id() != sub_tree.get_root_id()
+        self.assertNotEqual(base_tree.get_root_id(), sub_tree.get_root_id())
         sub_root_id = sub_tree.get_root_id()
         # this test checks the subdir is removed, so it needs to know the
         # control directory; that changes rarely so just hardcode (and check)

=== modified file 'bzrlib/tests/test_upgrade.py'
--- bzrlib/tests/test_upgrade.py	2008-03-14 21:31:15 +0000
+++ bzrlib/tests/test_upgrade.py	2008-04-24 07:22:53 +0000
@@ -155,7 +155,7 @@
         upgrade('.', bzrdir.BzrDirFormat6())
         transport = get_transport('.')
         transport.delete_multi(['.bzr/pending-merges', '.bzr/inventory'])
-        assert not transport.has('.bzr/stat-cache')
+        self.assertFalse(transport.has('.bzr/stat-cache'))
         # XXX: upgrade fails if a backup.bzr is already present
         # -- David Allouche 2006-08-11
         transport.delete_tree('backup.bzr')

=== modified file 'bzrlib/tests/transport_util.py'
--- bzrlib/tests/transport_util.py	2007-09-24 15:01:26 +0000
+++ bzrlib/tests/transport_util.py	2008-04-24 07:22:53 +0000
@@ -65,7 +65,8 @@
     hooks = TransportHooks()
 
     def __init__(self, base, _from_transport=None):
-        assert base.startswith(_hooked_scheme + '://')
+        if not base.startswith(_hooked_scheme + '://'):
+            raise ValueError(base)
         # We need to trick the backing transport class about the scheme used
         # We'll do the reverse when we need to talk to the backing server
         fake_base = _change_scheme_in(base, _hooked_scheme, _backing_scheme)

=== modified file 'bzrlib/tests/tree_implementations/test_inv.py'
--- bzrlib/tests/tree_implementations/test_inv.py	2007-12-18 15:22:47 +0000
+++ bzrlib/tests/tree_implementations/test_inv.py	2008-04-24 07:22:53 +0000
@@ -29,129 +29,6 @@
 from bzrlib.uncommit import uncommit
 
 
-class TestEntryDiffing(TestCaseWithTree):
-
-    def setUp(self):
-        super(TestEntryDiffing, self).setUp()
-        self.wt = self.make_branch_and_tree('.')
-        self.branch = self.wt.branch
-        open('file', 'wb').write('foo\n')
-        open('binfile', 'wb').write('foo\n')
-        self.wt.add(['file'], ['fileid'])
-        self.wt.add(['binfile'], ['binfileid'])
-        if has_symlinks():
-            os.symlink('target1', 'symlink')
-            self.wt.add(['symlink'], ['linkid'])
-        self.wt.commit('message_1', rev_id = '1')
-        open('file', 'wb').write('bar\n')
-        open('binfile', 'wb').write('x' * 1023 + '\x00\n')
-        if has_symlinks():
-            os.unlink('symlink')
-            os.symlink('target2', 'symlink')
-        self.tree_1 = self.branch.repository.revision_tree('1')
-        self.inv_1 = self.branch.repository.get_inventory('1')
-        self.file_1 = self.inv_1['fileid']
-        self.file_1b = self.inv_1['binfileid']
-        self.tree_2 = self.workingtree_to_test_tree(self.wt)
-        self.tree_2.lock_read()
-        self.addCleanup(self.tree_2.unlock)
-        self.inv_2 = self.tree_2.inventory
-        self.file_2 = self.inv_2['fileid']
-        self.file_2b = self.inv_2['binfileid']
-        if has_symlinks():
-            self.link_1 = self.inv_1['linkid']
-            self.link_2 = self.inv_2['linkid']
-
-    def test_file_diff_deleted(self):
-        output = StringIO()
-        self.applyDeprecated(one_zero,
-                             self.file_1.diff,
-                             internal_diff,
-                             "old_label", self.tree_1,
-                             "/dev/null", None, None,
-                             output)
-        self.assertEqual(output.getvalue(), "--- old_label\n"
-                                            "+++ /dev/null\n"
-                                            "@@ -1,1 +0,0 @@\n"
-                                            "-foo\n"
-                                            "\n")
-
-    def test_file_diff_added(self):
-        output = StringIO()
-        self.applyDeprecated(one_zero,
-                             self.file_1.diff,
-                             internal_diff,
-                             "new_label", self.tree_1,
-                             "/dev/null", None, None,
-                             output, reverse=True)
-        self.assertEqual(output.getvalue(), "--- /dev/null\n"
-                                            "+++ new_label\n"
-                                            "@@ -0,0 +1,1 @@\n"
-                                            "+foo\n"
-                                            "\n")
-
-    def test_file_diff_changed(self):
-        output = StringIO()
-        self.applyDeprecated(one_zero,
-                             self.file_1.diff,
-                             internal_diff,
-                             "/dev/null", self.tree_1,
-                             "new_label", self.file_2, self.tree_2,
-                             output)
-        self.assertEqual(output.getvalue(), "--- /dev/null\n"
-                                            "+++ new_label\n"
-                                            "@@ -1,1 +1,1 @@\n"
-                                            "-foo\n"
-                                            "+bar\n"
-                                            "\n")
-        
-    def test_file_diff_binary(self):
-        output = StringIO()
-        self.applyDeprecated(one_zero,
-                             self.file_1.diff,
-                             internal_diff,
-                             "/dev/null", self.tree_1,
-                             "new_label", self.file_2b, self.tree_2,
-                             output)
-        self.assertEqual(output.getvalue(), 
-                         "Binary files /dev/null and new_label differ\n")
-
-    def test_link_diff_deleted(self):
-        self.requireFeature(SymlinkFeature)
-        output = StringIO()
-        self.applyDeprecated(one_zero,
-                             self.link_1.diff,
-                             internal_diff, "old_label",
-                             self.tree_1, "/dev/null", None, None,
-                             output)
-        self.assertEqual(output.getvalue(),
-                         "=== target was 'target1'\n")
-
-    def test_link_diff_added(self):
-        self.requireFeature(SymlinkFeature)
-        output = StringIO()
-        self.applyDeprecated(one_zero,
-                             self.link_1.diff,
-                             internal_diff,
-                             "new_label", self.tree_1,
-                             "/dev/null", None, None,
-                             output, reverse=True)
-        self.assertEqual(output.getvalue(),
-                         "=== target is 'target1'\n")
-
-    def test_link_diff_changed(self):
-        self.requireFeature(SymlinkFeature)
-        output = StringIO()
-        self.applyDeprecated(one_zero,
-                             self.link_1.diff,
-                             internal_diff,
-                             "/dev/null", self.tree_1,
-                             "new_label", self.link_2, self.tree_2,
-                             output)
-        self.assertEqual(output.getvalue(),
-                         "=== target changed 'target1' => 'target2'\n")
-
-
 class TestPreviousHeads(TestCaseWithTree):
 
     def setUp(self):

=== modified file 'bzrlib/tests/treeshape.py'
--- bzrlib/tests/treeshape.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/treeshape.py	2008-04-24 07:22:53 +0000
@@ -65,7 +65,8 @@
         filenames.sort()
         for fn in filenames:
             fullpath = pathjoin(dirpath, fn)
-            assert not (fullpath[-1] in '@/')
+            if (fullpath[-1] in '@/'):
+                raise AssertionError(fullpath)
             info = os.lstat(fullpath)
             if stat.S_ISLNK(info.st_mode):
                 yield (fullpath + '@', os.readlink(fullpath))

=== modified file 'bzrlib/tests/workingtree_implementations/test_add_reference.py'
--- bzrlib/tests/workingtree_implementations/test_add_reference.py	2007-03-06 13:08:53 +0000
+++ bzrlib/tests/workingtree_implementations/test_add_reference.py	2008-04-24 07:22:53 +0000
@@ -36,13 +36,19 @@
         sub_tree.commit('commit', rev_id='sub_1')
         return tree, sub_tree
 
+    def _references_unsupported(self, tree):
+        if tree.__class__ in TREES_NOT_SUPPORTING_REFERENCES:
+            raise tests.TestSkipped('Tree format does not support references')
+        else:
+            self.fail('%r does not support references but should'
+                % (tree, ))
+
     def make_nested_trees(self):
         tree, sub_tree = self.make_trees()
         try:
             tree.add_reference(sub_tree)
         except errors.UnsupportedOperation:
-            assert tree.__class__ in TREES_NOT_SUPPORTING_REFERENCES
-            raise tests.TestSkipped('Tree format does not support references')
+            self._references_unsupported(tree)
         return tree, sub_tree
 
     def test_add_reference(self):
@@ -76,8 +82,7 @@
             self.assertRaises(errors.BadReferenceTarget, tree.add_reference, 
                               sub_tree)
         except errors.UnsupportedOperation:
-            assert tree.__class__ in TREES_NOT_SUPPORTING_REFERENCES
-            raise tests.TestSkipped('Tree format does not support references')
+            self._references_unsupported(tree)
 
     def test_root_present(self):
         """Subtree root is present, though not the working tree root"""
@@ -87,8 +92,7 @@
             self.assertRaises(errors.BadReferenceTarget, tree.add_reference, 
                               sub_tree)
         except errors.UnsupportedOperation:
-            assert tree.__class__ in TREES_NOT_SUPPORTING_REFERENCES
-            raise tests.TestSkipped('Tree format does not support references')
+            self._references_unsupported(tree)
 
     def test_add_non_subtree(self):
         tree, sub_tree = self.make_trees()
@@ -98,8 +102,7 @@
             self.assertRaises(errors.BadReferenceTarget, tree.add_reference, 
                               sibling)
         except errors.UnsupportedOperation:
-            assert tree.__class__ in TREES_NOT_SUPPORTING_REFERENCES
-            raise tests.TestSkipped('Tree format does not support references')
+            self._references_unsupported(tree)
 
     def test_get_nested_tree(self):
         tree, sub_tree = self.make_nested_trees()

=== modified file 'bzrlib/textinv.py'
--- bzrlib/textinv.py	2006-10-16 01:50:48 +0000
+++ bzrlib/textinv.py	2008-04-24 07:22:53 +0000
@@ -36,7 +36,8 @@
 
 
 def unescape(s):
-    assert s.find(' ') == -1
+    if s.find(' ') != -1:
+        raise AssertionError()
     s = (s.replace(r'\x20', ' ')
          .replace(r'\x09', '\t')
          .replace(r'\x0a', '\n')

=== modified file 'bzrlib/textui.py'
--- bzrlib/textui.py	2006-10-11 23:08:27 +0000
+++ bzrlib/textui.py	2008-04-24 07:22:53 +0000
@@ -25,11 +25,13 @@
         kind_ch = '/'
     elif kind == 'symlink':
         kind_ch = '->'
+    elif kind == 'file':
+        kind_ch = ''
     else:
-        assert kind == 'file', ("can't handle file of type %r" % kind)
-        kind_ch = ''
+        raise ValueError(kind)
 
-    assert len(state) == 1
+    if len(state) != 1:
+        raise ValueError(state)
         
     if to_file is None:
         to_file = sys.stdout

=== modified file 'bzrlib/timestamp.py'
--- bzrlib/timestamp.py	2007-04-19 08:03:19 +0000
+++ bzrlib/timestamp.py	2008-04-24 07:22:53 +0000
@@ -47,7 +47,8 @@
     >>> format_highres_date(1152428738.867522, 19800)
     'Sun 2006-07-09 12:35:38.867522001 +0530'
     """
-    assert isinstance(t, float)
+    if not isinstance(t, float):
+        raise ValueError(t)
 
     # This has to be formatted for "original" date, so that the
     # revision XML entry will be reproduced faithfully.
@@ -129,8 +130,9 @@
 
     Inverse of parse_patch_date.
     """
-    assert offset % 60 == 0, \
-        "can't represent timezone %s offset by fractional minutes" % offset
+    if offset % 60 != 0:
+        raise ValueError(
+        "can't represent timezone %s offset by fractional minutes" % offset)
     # so that we don't need to do calculations on pre-epoch times, 
     # which doesn't work with win32 python gmtime, we always
     # give the epoch in utc
@@ -151,8 +153,9 @@
     """
     secs_str = date_str[:-6]
     offset_str = date_str[-5:]
-    assert len(offset_str) == 5, \
-            "invalid timezone %r" % offset_str
+    if len(offset_str) != 5:
+        raise ValueError(
+            "invalid timezone %r" % offset_str)
     offset_hours, offset_mins = offset_str[:3], offset_str[3:]
     offset = int(offset_hours) * 3600 + int(offset_mins) * 60
     tm_time = time.strptime(secs_str, '%Y-%m-%d %H:%M:%S')

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2008-03-19 01:43:43 +0000
+++ bzrlib/trace.py	2008-04-24 07:22:53 +0000
@@ -295,7 +295,6 @@
     This flushes, but does not close the trace file.
     
     Takes the memento returned from _push_log_file."""
-    assert magic == 'log_memento'
     global _trace_file
     _trace_file = old_trace_file
     bzr_logger = logging.getLogger('bzr')

=== modified file 'bzrlib/transactions.py'
--- bzrlib/transactions.py	2006-10-11 23:08:27 +0000
+++ bzrlib/transactions.py	2008-04-24 07:22:53 +0000
@@ -79,7 +79,8 @@
 
     def set_cache_size(self, size):
         """Set a new cache size."""
-        assert -1 <= size
+        if size < -1:
+            raise ValueError(size)
         self._limit = size
         self._trim()
 

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2008-04-04 04:20:19 +0000
+++ bzrlib/transform.py	2008-04-24 07:22:53 +0000
@@ -440,7 +440,8 @@
 
     def version_file(self, file_id, trans_id):
         """Schedule a file to become versioned."""
-        assert file_id is not None
+        if file_id is None:
+            raise ValueError()
         unique_add(self._new_id, trans_id, file_id)
         unique_add(self._r_new_id, file_id, trans_id)
 
@@ -510,8 +511,6 @@
         applied.
         """
         try:
-            # there is a new id for this file
-            assert self._new_id[trans_id] is not None
             return self._new_id[trans_id]
         except KeyError:
             if trans_id in self._removed_id:
@@ -1242,7 +1241,6 @@
                         file_id = self._tree.get_root_id()
                     else:
                         file_id = self.tree_file_id(trans_id)
-                    assert file_id is not None
                     # File-id isn't really being deleted, just moved
                     if file_id in self._r_new_id:
                         continue
@@ -1664,7 +1662,8 @@
     new_conflicts = set()
     for c_type, conflict in ((c[0], c) for c in conflicts):
         # Anything but a 'duplicate' would indicate programmer error
-        assert c_type == 'duplicate', c_type
+        if c_type != 'duplicate':
+            raise AssertionError(c_type)
         # Now figure out which is new and which is old
         if tt.new_contents(conflict[1]):
             new_file = conflict[1]
@@ -1942,8 +1941,8 @@
                     # preserve the execute bit when backing up
                     if keep_content and executable[0] == executable[1]:
                         tt.set_executability(executable[1], trans_id)
-                else:
-                    assert kind[1] is None
+                elif kind[1] != None:
+                    raise AssertionError(kind[1])
             if versioned == (False, True):
                 tt.version_file(file_id, trans_id)
             if versioned == (True, False):

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2008-04-02 10:05:36 +0000
+++ bzrlib/transport/__init__.py	2008-04-24 07:22:53 +0000
@@ -135,7 +135,8 @@
                              register_netloc=False):
     transport_list_registry.register_transport(prefix, help)
     if register_netloc:
-        assert prefix.endswith('://')
+        if not prefix.endswith('://'):
+            raise ValueError(prefix)
         register_urlparse_netloc_protocol(prefix[:-3])
 
 
@@ -404,8 +405,6 @@
         object or string to another one.
         This just gives them something easy to call.
         """
-        assert not isinstance(from_file, basestring), \
-            '_pump should only be called on files not %s' % (type(from_file,))
         return osutils.pumpfile(from_file, to_file)
 
     def _get_total(self, multi):
@@ -1000,8 +999,9 @@
 
         :returns: the length of relpath before the content was written to it.
         """
-        assert isinstance(bytes, str), \
-            'bytes must be a plain string, not %s' % type(bytes)
+        if not isinstance(bytes, str):
+            raise TypeError(
+                'bytes must be a plain string, not %s' % type(bytes))
         return self.append_file(relpath, StringIO(bytes), mode=mode)
 
     def append_multi(self, files, pb=None):
@@ -1604,7 +1604,8 @@
             transport, last_err = _try_transport_factories(base, factory_list)
             if transport:
                 if possible_transports is not None:
-                    assert transport not in possible_transports
+                    if transport in possible_transports:
+                        raise AssertionError()
                     possible_transports.append(transport)
                 return transport
 

=== modified file 'bzrlib/transport/chroot.py'
--- bzrlib/transport/chroot.py	2007-12-05 01:58:00 +0000
+++ bzrlib/transport/chroot.py	2008-04-24 07:22:53 +0000
@@ -45,7 +45,6 @@
         self.backing_transport = backing_transport
 
     def _factory(self, url):
-        assert url.startswith(self.scheme)
         return ChrootTransport(self, url)
 
     def get_url(self):
@@ -79,7 +78,8 @@
 
     def _safe_relpath(self, relpath):
         safe_relpath = self._combine_paths(self.base_path, relpath)
-        assert safe_relpath.startswith('/')
+        if not safe_relpath.startswith('/'):
+            raise ValueError(safe_relpath)
         return safe_relpath[1:]
 
     # Transport methods

=== modified file 'bzrlib/transport/decorator.py'
--- bzrlib/transport/decorator.py	2007-10-04 22:00:07 +0000
+++ bzrlib/transport/decorator.py	2008-04-24 07:22:53 +0000
@@ -45,9 +45,10 @@
             need to share state across clones.
         """
         prefix = self._get_url_prefix()
-        assert url.startswith(prefix), \
+        if not url.startswith(prefix):
+            raise ValueError(
                 "url %r doesn't start with decorator prefix %r" % \
-                (url, prefix)
+                (url, prefix))
         decorated_url = url[len(prefix):]
         if _decorated is None:
             self._decorated = get_transport(decorated_url)

=== modified file 'bzrlib/transport/ftp.py'
--- bzrlib/transport/ftp.py	2008-03-30 01:41:50 +0000
+++ bzrlib/transport/ftp.py	2008-04-24 07:22:53 +0000
@@ -89,7 +89,8 @@
 
     def __init__(self, base, _from_transport=None):
         """Set the base path where files will be stored."""
-        assert base.startswith('ftp://') or base.startswith('aftp://')
+        if not (base.startswith('ftp://') or base.startswith('aftp://')):
+            raise ValueError(base)
         super(FtpTransport, self).__init__(base,
                                            _from_transport=_from_transport)
         self._unqualified_scheme = 'ftp'

=== modified file 'bzrlib/transport/http/__init__.py'
--- bzrlib/transport/http/__init__.py	2008-03-26 09:50:48 +0000
+++ bzrlib/transport/http/__init__.py	2008-04-24 07:22:53 +0000
@@ -52,8 +52,9 @@
     password manager.  Return the url, minus those auth parameters (which
     confuse urllib2).
     """
-    assert re.match(r'^(https?)(\+\w+)?://', url), \
-            'invalid absolute url %r' % url
+    if not re.match(r'^(https?)(\+\w+)?://', url):
+        raise ValueError(
+            'invalid absolute url %r' % (url,))
     scheme, netloc, path, query, fragment = urlparse.urlsplit(url)
 
     if '@' in netloc:

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2008-03-17 19:53:19 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2008-04-24 07:22:53 +0000
@@ -309,7 +309,8 @@
         # confused
         Request.__init__(self, 'CONNECT', request.get_full_url(),
                          connection=request.connection)
-        assert request.proxied_host is not None
+        if request.proxied_host is None:
+            raise AssertionError()
         self.proxied_host = request.proxied_host
 
     def get_selector(self):
@@ -502,8 +503,9 @@
         The request will be retried once if it fails.
         """
         connection = request.connection
-        assert connection is not None, \
-            'Cannot process a request without a connection'
+        if connection is None:
+            raise AssertionError(
+                'Cannot process a request without a connection')
 
         # Get all the headers
         headers = {}
@@ -595,7 +597,6 @@
 
     def https_open(self, request):
         connection = request.connection
-        assert isinstance(connection, HTTPSConnection)
         if connection.sock is None and \
                 connection.proxied_host is not None and \
                 request.get_method() != 'CONNECT' : # Don't loop

=== modified file 'bzrlib/transport/http/wsgi.py'
--- bzrlib/transport/http/wsgi.py	2008-01-16 09:49:01 +0000
+++ bzrlib/transport/http/wsgi.py	2008-04-24 07:22:53 +0000
@@ -144,7 +144,8 @@
 
         if adjusted_relpath.startswith('/'):
             adjusted_relpath = adjusted_relpath[1:]
-        assert not adjusted_relpath.startswith('/')
+        if adjusted_relpath.startswith('/'):
+            raise AssertionError(adjusted_relpath)
 
         transport = self.backing_transport.clone(adjusted_relpath)
         out_buffer = StringIO()

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2007-11-22 00:29:58 +0000
+++ bzrlib/transport/local.py	2008-04-24 07:22:53 +0000
@@ -96,7 +96,6 @@
     def abspath(self, relpath):
         """Return the full url to the given relative URL."""
         # TODO: url escape the result. RBC 20060523.
-        assert isinstance(relpath, basestring), (type(relpath), relpath)
         # jam 20060426 Using normpath on the real path, because that ensures
         #       proper handling of stuff like
         path = osutils.normpath(osutils.pathjoin(
@@ -511,7 +510,6 @@
         self._local_base = urlutils._win32_local_path_from_url(base)
 
     def abspath(self, relpath):
-        assert isinstance(relpath, basestring), (type(relpath), relpath)
         path = osutils.normpath(osutils.pathjoin(
                     self._local_base, urlutils.unescape(relpath)))
         return urlutils._win32_local_path_to_url(path)

=== modified file 'bzrlib/transport/memory.py'
--- bzrlib/transport/memory.py	2008-02-04 09:27:03 +0000
+++ bzrlib/transport/memory.py	2008-04-24 07:22:53 +0000
@@ -283,7 +283,6 @@
     """This makes a lock."""
 
     def __init__(self, path, transport):
-        assert isinstance(transport, MemoryTransport)
         self.path = path
         self.transport = transport
         if self.path in self.transport._locks:

=== modified file 'bzrlib/transport/remote.py'
--- bzrlib/transport/remote.py	2008-04-07 10:34:57 +0000
+++ bzrlib/transport/remote.py	2008-04-24 07:22:53 +0000
@@ -457,7 +457,6 @@
     """
 
     def _build_medium(self):
-        assert self.base.startswith('bzr://')
         return medium.SmartTCPClientMedium(self._host, self._port), None
 
 
@@ -469,7 +468,6 @@
     """
 
     def _build_medium(self):
-        assert self.base.startswith('bzr+ssh://')
         # ssh will prompt the user for a password if needed and if none is
         # provided but it will not give it back, so no credentials can be
         # stored.
@@ -491,8 +489,6 @@
     """
 
     def __init__(self, base, _from_transport=None, http_transport=None):
-        assert ( base.startswith('bzr+http://') or base.startswith('bzr+https://') )
-
         if http_transport is None:
             # FIXME: the password may be lost here because it appears in the
             # url only for an intial construction (when the url came from the

=== modified file 'bzrlib/transport/sftp.py'
--- bzrlib/transport/sftp.py	2008-04-10 09:16:39 +0000
+++ bzrlib/transport/sftp.py	2008-04-24 07:22:53 +0000
@@ -111,8 +111,6 @@
     __slots__ = ['path', 'lock_path', 'lock_file', 'transport']
 
     def __init__(self, path, transport):
-        assert isinstance(transport, SFTPTransport)
-
         self.lock_file = None
         self.path = path
         self.lock_path = path + '.write-lock'
@@ -164,7 +162,6 @@
     _max_request_size = 32768
 
     def __init__(self, base, _from_transport=None):
-        assert base.startswith('sftp://')
         super(SFTPTransport, self).__init__(base,
                                             _from_transport=_from_transport)
 
@@ -346,9 +343,10 @@
 
             if cur_data_len < cur_coalesced.length:
                 continue
-            assert cur_data_len == cur_coalesced.length, \
-                "Somehow we read too much: %s != %s" % (cur_data_len,
-                                                        cur_coalesced.length)
+            if cur_data_len != cur_coalesced.length:
+                raise AssertionError(
+                    "Somehow we read too much: %s != %s" 
+                    % (cur_data_len, cur_coalesced.length))
             all_data = ''.join(cur_data)
             cur_data = []
             cur_data_len = 0
@@ -948,10 +946,11 @@
     def setUp(self, backing_server=None):
         # XXX: TODO: make sftpserver back onto backing_server rather than local
         # disk.
-        assert (backing_server is None or
-                isinstance(backing_server, local.LocalURLServer)), (
-            "backing_server should not be %r, because this can only serve the "
-            "local current working directory." % (backing_server,))
+        if not (backing_server is None or
+                isinstance(backing_server, local.LocalURLServer)):
+            raise AssertionError(
+                "backing_server should not be %r, because this can only serve the "
+                "local current working directory." % (backing_server,))
         self._original_vendor = ssh._ssh_vendor_manager._cached_ssh_vendor
         ssh._ssh_vendor_manager._cached_ssh_vendor = self._vendor
         if sys.platform == 'win32':

=== modified file 'bzrlib/transport/ssh.py'
--- bzrlib/transport/ssh.py	2008-04-10 09:16:39 +0000
+++ bzrlib/transport/ssh.py	2008-04-24 07:22:53 +0000
@@ -402,11 +402,6 @@
 
     def _get_vendor_specific_argv(self, username, host, port, subsystem=None,
                                   command=None):
-        assert subsystem is not None or command is not None, (
-            'Must specify a command or subsystem')
-        if subsystem is not None:
-            assert command is None, (
-                'subsystem and command are mutually exclusive')
         args = ['ssh',
                 '-oForwardX11=no', '-oForwardAgent=no',
                 '-oClearAllForwardings=yes', '-oProtocol=2',
@@ -429,11 +424,6 @@
 
     def _get_vendor_specific_argv(self, username, host, port, subsystem=None,
                                   command=None):
-        assert subsystem is not None or command is not None, (
-            'Must specify a command or subsystem')
-        if subsystem is not None:
-            assert command is None, (
-                'subsystem and command are mutually exclusive')
         args = ['ssh', '-x']
         if port is not None:
             args.extend(['-p', str(port)])
@@ -453,11 +443,6 @@
 
     def _get_vendor_specific_argv(self, username, host, port, subsystem=None,
                                   command=None):
-        assert subsystem is not None or command is not None, (
-            'Must specify a command or subsystem')
-        if subsystem is not None:
-            assert command is None, (
-                'subsystem and command are mutually exclusive')
         args = ['plink', '-x', '-a', '-ssh', '-2', '-batch']
         if port is not None:
             args.extend(['-P', str(port)])

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2008-03-14 16:32:01 +0000
+++ bzrlib/tree.py	2008-04-24 07:22:53 +0000
@@ -519,7 +519,6 @@
         return False
 
     def kind(self, file_id):
-        assert self._inventory[file_id].kind == "directory"
         return "directory"
 
     def list_files(self, include_root=False):
@@ -568,7 +567,6 @@
         # what happened to the file that used to have
         # this name.  There are two possibilities: either it was
         # deleted entirely, or renamed.
-        assert old_id
         if new_inv.has_id(old_id):
             return 'X', old_inv.id2path(old_id), new_inv.id2path(old_id)
         else:

=== modified file 'bzrlib/treebuilder.py'
--- bzrlib/treebuilder.py	2006-09-22 04:52:17 +0000
+++ bzrlib/treebuilder.py	2008-04-24 07:22:53 +0000
@@ -45,7 +45,6 @@
             self._tree.add('', 'root-id', 'directory')
             self._root_done = True
         for name in recipe:
-            assert isinstance(name, basestring)
             if name[-1] == '/':
                 self._tree.mkdir(name[:-1])
             else:

=== modified file 'bzrlib/tuned_gzip.py'
--- bzrlib/tuned_gzip.py	2007-09-21 01:36:48 +0000
+++ bzrlib/tuned_gzip.py	2008-04-24 07:22:53 +0000
@@ -149,7 +149,8 @@
 
         if buf == "":
             self._add_read_data(self.decompress.flush())
-            assert len(self.decompress.unused_data) >= 8, "what does flush do?"
+            if len(self.decompress.unused_data) < 8:
+                raise AssertionError("what does flush do?")
             self._gzip_tail = self.decompress.unused_data[0:8]
             self._read_eof()
             # tell the driving read() call we have stuffed all the data
@@ -175,7 +176,8 @@
                 self._gzip_tail = self.decompress.unused_data[0:8]
             elif seek_length < 0:
                 # we haven't read enough to check the checksum.
-                assert -8 < seek_length, "too great a seek."
+                if not (-8 < seek_length):
+                    raise AssertionError("too great a seek")
                 buf = self.fileobj.read(-seek_length)
                 self._gzip_tail = self.decompress.unused_data + buf
             else:
@@ -200,7 +202,8 @@
         # We then check the that the computed CRC and size of the
         # uncompressed data matches the stored values.  Note that the size
         # stored is the true file size mod 2**32.
-        assert len(self._gzip_tail) == 8, "gzip trailer is incorrect length."
+        if not (len(self._gzip_tail) == 8):
+            raise AssertionError("gzip trailer is incorrect length.")
         crc32, isize = struct.unpack("<LL", self._gzip_tail)
         # note that isize is unsigned - it can exceed 2GB
         if crc32 != U32(self.crc):

=== modified file 'bzrlib/urlutils.py'
--- bzrlib/urlutils.py	2008-02-27 18:24:39 +0000
+++ bzrlib/urlutils.py	2008-04-24 07:22:53 +0000
@@ -75,10 +75,10 @@
     
     This assumes that both paths are already fully specified file:// URLs.
     """
-    assert len(base) >= MIN_ABS_FILEURL_LENGTH, ('Length of base must be equal or'
-        ' exceed the platform minimum url length (which is %d)' % 
-        MIN_ABS_FILEURL_LENGTH)
-
+    if len(base) < MIN_ABS_FILEURL_LENGTH:
+        raise ValueError('Length of base must be equal or'
+            ' exceed the platform minimum url length (which is %d)' %
+            MIN_ABS_FILEURL_LENGTH)
     base = local_path_from_url(base)
     path = local_path_from_url(path)
     return escape(osutils.relpath(base, path))
@@ -574,7 +574,8 @@
     :return: A unicode string which can be safely encoded into the 
          specified encoding.
     """
-    assert encoding is not None, 'you cannot specify None for the display encoding.'
+    if encoding is None:
+        raise ValueError('you cannot specify None for the display encoding')
     if url.startswith('file://'):
         try:
             path = local_path_from_url(url)

=== modified file 'bzrlib/version_info_formats/__init__.py'
--- bzrlib/version_info_formats/__init__.py	2008-02-26 21:18:26 +0000
+++ bzrlib/version_info_formats/__init__.py	2008-04-24 07:22:53 +0000
@@ -141,8 +141,9 @@
         rev_hist = self._branch.revision_history()
         if self._working_tree is not None:
             last_rev = self._working_tree.last_revision()
-            assert last_rev in rev_hist, \
-                "Working Tree's last revision not in branch.revision_history"
+            if last_rev not in rev_hist:
+                raise AssertionError(
+                    "Working Tree's last revision not in branch.revision_history")
             rev_hist = rev_hist[:rev_hist.index(last_rev)+1]
 
         repository =  self._branch.repository

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2008-04-09 00:34:54 +0000
+++ bzrlib/versionedfile.py	2008-04-24 07:22:53 +0000
@@ -712,8 +712,9 @@
                 ch_b = ch_a = True
                 lines_b.append(line)
             else:
-                assert state in ('irrelevant', 'ghost-a', 'ghost-b', 
-                                 'killed-base', 'killed-both'), state
+                if state not in ('irrelevant', 'ghost-a', 'ghost-b',
+                        'killed-base', 'killed-both'):
+                    raise AssertionError(state)
         for struct in outstanding_struct():
             yield struct
 

=== modified file 'bzrlib/weave.py'
--- bzrlib/weave.py	2008-04-09 00:34:54 +0000
+++ bzrlib/weave.py	2008-04-24 07:22:53 +0000
@@ -312,7 +312,6 @@
 
         :param nostore_sha: See VersionedFile.add_lines.
         """
-        assert isinstance(version_id, basestring)
         self._check_lines_not_unicode(lines)
         self._check_lines_are_lines(lines)
         if not sha1:
@@ -393,14 +392,8 @@
             #print 'raw match', tag, i1, i2, j1, j2
             if tag == 'equal':
                 continue
-
             i1 = basis_lineno[i1]
             i2 = basis_lineno[i2]
-
-            assert 0 <= j1 <= j2 <= len(lines)
-
-            #print tag, i1, i2, j1, j2
-
             # the deletion and insertion are handled separately.
             # first delete the region.
             if i1 != i2:
@@ -507,15 +500,12 @@
                 elif c == '}':
                     istack.pop()
                 elif c == '[':
-                    assert self._names[v] not in dset
                     dset.add(self._names[v])
                 elif c == ']':
                     dset.remove(self._names[v])
                 else:
                     raise WeaveFormatError('unexpected instruction %r' % v)
             else:
-                assert l.__class__ in (str, unicode)
-                assert istack
                 yield lineno, istack[-1], frozenset(dset), l
             lineno += 1
 
@@ -631,22 +621,19 @@
                 c, v = l
                 isactive = None
                 if c == '{':
-                    assert v not in iset
                     istack.append(v)
                     iset.add(v)
                 elif c == '}':
                     iset.remove(istack.pop())
                 elif c == '[':
                     if v in included:
-                        assert v not in dset
                         dset.add(v)
-                else:
-                    assert c == ']'
+                elif c == ']':
                     if v in included:
-                        assert v in dset
                         dset.remove(v)
+                else:
+                    raise AssertionError()
             else:
-                assert l.__class__ in (str, unicode)
                 if isactive is None:
                     isactive = (not dset) and istack and (istack[-1] in included)
                 if isactive:
@@ -690,7 +677,6 @@
     def num_versions(self):
         """How many versions are in this weave?"""
         l = len(self._parents)
-        assert l == len(self._sha1s)
         return l
 
     __len__ = num_versions
@@ -722,8 +708,10 @@
             for p in self._parents[i]:
                 new_inc.update(inclusions[self._idx_to_name(p)])
 
-            assert set(new_inc) == set(self.get_ancestry(name)), \
-                'failed %s != %s' % (set(new_inc), set(self.get_ancestry(name)))
+            if set(new_inc) != set(self.get_ancestry(name)):
+                raise AssertionError(
+                    'failed %s != %s' 
+                    % (set(new_inc), set(self.get_ancestry(name))))
             inclusions[name] = new_inc
 
         nlines = len(self._weave)

=== modified file 'bzrlib/weavefile.py'
--- bzrlib/weavefile.py	2007-10-16 18:26:12 +0000
+++ bzrlib/weavefile.py	2008-04-24 07:22:53 +0000
@@ -72,7 +72,6 @@
 
     for l in weave._weave:
         if isinstance(l, tuple):
-            assert l[0] in '{}[]'
             if l[0] == '}':
                 f.write('}\n')
             else:
@@ -81,10 +80,8 @@
             if not l:
                 f.write(', \n')
             elif l[-1] == '\n':
-                assert l.find('\n', 0, -1) == -1
                 f.write('. ' + l)
             else:
-                assert l.find('\n') == -1
                 f.write(', ' + l + '\n')
 
     f.write('W\n')
@@ -140,21 +137,13 @@
                 w._parents.append(map(int, l[2:].split(' ')))
             else:
                 w._parents.append([])
-
             l = lines.next()[:-1]
-            assert '1 ' == l[0:2]
             w._sha1s.append(l[2:])
-                
             l = lines.next()
-            assert 'n ' == l[0:2]
             name = l[2:-1]
-            assert name not in w._name_map
             w._names.append(name)
             w._name_map[name] = ver
-                
             l = lines.next()
-            assert l == '\n'
-
             ver += 1
         elif l == 'w\n':
             break
@@ -173,9 +162,5 @@
         elif l == '}\n':
             w._weave.append(('}', None))
         else:
-            assert l[0] in '{[]', l
-            assert l[1] == ' ', l
             w._weave.append((intern(l[0]), int(l[2:])))
-
     return w
-    

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2008-03-15 14:07:55 +0000
+++ bzrlib/workingtree.py	2008-04-24 07:22:53 +0000
@@ -222,8 +222,6 @@
         if not _internal:
             raise errors.BzrError("Please use bzrdir.open_workingtree or "
                 "WorkingTree.open() to obtain a WorkingTree.")
-        assert isinstance(basedir, basestring), \
-            "base directory %r is not a string" % basedir
         basedir = safe_unicode(basedir)
         mutter("opening working tree %r", basedir)
         if deprecated_passed(branch):
@@ -237,9 +235,6 @@
             self._control_files = self.branch.control_files
         else:
             # assume all other formats have their own control files.
-            assert isinstance(_control_files, LockableFiles), \
-                    "_control_files must be a LockableFiles, not %r" \
-                    % _control_files
             self._control_files = _control_files
         # update the whole cache up front and write to disk if anything changed;
         # in the future we might want to do this more selectively
@@ -318,7 +313,6 @@
             False then the inventory is the same as that on disk and any
             serialisation would be unneeded overhead.
         """
-        assert inv.root is not None
         self._inventory = inv
         self._inventory_is_modified = dirty
 
@@ -664,7 +658,6 @@
         # function - they should be part of lock_write and unlock.
         inv = self.inventory
         for f, file_id, kind in zip(files, ids, kinds):
-            assert kind is not None
             if file_id is None:
                 inv.add_path(f, kind=kind)
             else:
@@ -1269,7 +1262,8 @@
                                        DeprecationWarning)
 
         # check destination directory
-        assert not isinstance(from_paths, basestring)
+        if isinstance(from_paths, basestring):
+            raise ValueError()
         inv = self.inventory
         to_abs = self.abspath(to_dir)
         if not isdir(to_abs):
@@ -1820,7 +1814,6 @@
 
     def _write_basis_inventory(self, xml):
         """Write the basis inventory XML to the basis-inventory file"""
-        assert isinstance(xml, str), 'serialised xml must be bytestring.'
         path = self._basis_inventory_name()
         sio = StringIO(xml)
         self._control_files.put(path, sio)
@@ -2739,7 +2732,6 @@
 
     @classmethod
     def unregister_format(klass, format):
-        assert klass._formats[format.get_format_string()] is format
         del klass._formats[format.get_format_string()]
 
 

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2008-04-09 00:34:54 +0000
+++ bzrlib/workingtree_4.py	2008-04-24 07:22:53 +0000
@@ -131,18 +131,12 @@
         """
         self._format = _format
         self.bzrdir = _bzrdir
-        assert isinstance(basedir, basestring), \
-            "base directory %r is not a string" % basedir
         basedir = safe_unicode(basedir)
         mutter("opening working tree %r", basedir)
         self._branch = branch
-        assert isinstance(self.branch, bzrlib.branch.Branch), \
-            "branch %r is not a Branch" % self.branch
         self.basedir = realpath(basedir)
         # if branch is at our basedir and is a format 6 or less
         # assume all other formats have their own control files.
-        assert isinstance(_control_files, LockableFiles), \
-            "_control_files must be a LockableFiles, not %r" % _control_files
         self._control_files = _control_files
         self._dirty = None
         #-------------
@@ -317,7 +311,8 @@
         state._read_dirblocks_if_needed()
         root_key, current_entry = self._get_entry(path='')
         current_id = root_key[2]
-        assert current_entry[0][0] == 'd' # directory
+        if not (current_entry[0][0] == 'd'): # directory
+            raise AssertionError(current_entry)
         inv = Inventory(root_id=current_id)
         # Turn some things into local variables
         minikind_to_kind = dirstate.DirState._minikind_to_kind
@@ -356,18 +351,22 @@
                     # add this entry to the parent map.
                     parent_ies[(dirname + '/' + name).strip('/')] = inv_entry
                 elif kind == 'tree-reference':
-                    assert self._repo_supports_tree_reference, \
-                        "repository of %r " \
-                        "doesn't support tree references " \
-                        "required by entry %r" \
-                        % (self, name)
+                    if not self._repo_supports_tree_reference:
+                        raise AssertionError(
+                            "repository of %r "
+                            "doesn't support tree references "
+                            "required by entry %r"
+                            % (self, name))
                     inv_entry.reference_revision = link_or_sha1 or None
                 elif kind != 'symlink':
                     raise AssertionError("unknown kind %r" % kind)
                 # These checks cost us around 40ms on a 55k entry tree
-                assert file_id not in inv_byid, ('file_id %s already in'
-                    ' inventory as %s' % (file_id, inv_byid[file_id]))
-                assert name_unicode not in parent_ie.children
+                if file_id in inv_byid:
+                    raise AssertionError('file_id %s already in'
+                        ' inventory as %s' % (file_id, inv_byid[file_id]))
+                if name_unicode in parent_ie.children:
+                    raise AssertionError('name %r already in parent'
+                        % (name_unicode,))
                 inv_byid[file_id] = inv_entry
                 parent_ie.children[name_unicode] = inv_entry
         self._inventory = inv
@@ -552,8 +551,9 @@
         Note: The caller is expected to take a read-lock before calling this.
         """
         relpath = self.id2path(file_id)
-        assert relpath != None, \
-            "path for id {%s} is None!" % file_id
+        if relpath == None:
+            raise AssertionError(
+                "path for id {%s} is None!" % file_id)
         return self._kind(relpath)
 
     def _kind(self, relpath):
@@ -631,10 +631,9 @@
         result = []
         if not from_paths:
             return result
-
         state = self.current_dirstate()
-
-        assert not isinstance(from_paths, basestring)
+        if isinstance(from_paths, basestring):
+            raise ValueError()
         to_dir_utf8 = to_dir.encode('utf8')
         to_entry_dirname, to_basename = os.path.split(to_dir_utf8)
         id_index = state._get_id_index()
@@ -795,7 +794,8 @@
                 if minikind == 'd':
                     def update_dirblock(from_dir, to_key, to_dir_utf8):
                         """Recursively update all entries in this dirblock."""
-                        assert from_dir != '', "renaming root not supported"
+                        if from_dir == '':
+                            raise AssertionError("renaming root not supported")
                         from_key = (from_dir, '')
                         from_block_idx, present = \
                             state._find_block_index_from_key(from_key)
@@ -814,7 +814,8 @@
 
                         # Grab a copy since move_one may update the list.
                         for entry in from_block[1][:]:
-                            assert entry[0][0] == from_dir
+                            if not (entry[0][0] == from_dir):
+                                raise AssertionError()
                             cur_details = entry[1][0]
                             to_key = (to_dir_utf8, entry[0][1], entry[0][2])
                             from_path_utf8 = osutils.pathjoin(entry[0][0], entry[0][1])
@@ -1033,9 +1034,10 @@
         """Change the last revision in the working tree."""
         parents = self.get_parent_ids()
         if new_revision in (NULL_REVISION, None):
-            assert len(parents) < 2, (
-                "setting the last parent to none with a pending merge is "
-                "unsupported.")
+            if len(parents) >= 2:
+                raise AssertionError(
+                    "setting the last parent to none with a pending merge is "
+                    "unsupported.")
             self.set_parent_ids([])
         else:
             self.set_parent_ids([new_revision] + parents[1:],
@@ -1240,7 +1242,8 @@
 
     def update_basis_by_delta(self, new_revid, delta):
         """See MutableTree.update_basis_by_delta."""
-        assert self.last_revision() != new_revid
+        if self.last_revision() == new_revid:
+            raise AssertionError()
         self.current_dirstate().update_basis_by_delta(delta, new_revid)
 
     @needs_read_lock
@@ -1250,8 +1253,9 @@
     @needs_tree_write_lock
     def _write_inventory(self, inv):
         """Write inventory as the current inventory."""
-        assert not self._dirty, ("attempting to write an inventory when the "
-            "dirstate is dirty will cause data loss")
+        if self._dirty:
+            raise AssertionError("attempting to write an inventory when the "
+                "dirstate is dirty will lose pending changes")
         self.current_dirstate().set_state_from_inventory(inv)
         self._make_dirty(reset_inventory=False)
         if self._inventory is not None:
@@ -1467,19 +1471,23 @@
 
         This is relatively expensive: we have to walk the entire dirstate.
         """
-        assert self._locked, 'cannot generate inventory of an unlocked '\
-            'dirstate revision tree'
+        if not self._locked:
+            raise AssertionError(
+                'cannot generate inventory of an unlocked '
+                'dirstate revision tree')
         # separate call for profiling - makes it clear where the costs are.
         self._dirstate._read_dirblocks_if_needed()
-        assert self._revision_id in self._dirstate.get_parent_ids(), \
-            'parent %s has disappeared from %s' % (
-            self._revision_id, self._dirstate.get_parent_ids())
+        if self._revision_id not in self._dirstate.get_parent_ids():
+            raise AssertionError(
+                'parent %s has disappeared from %s' % (
+                self._revision_id, self._dirstate.get_parent_ids()))
         parent_index = self._dirstate.get_parent_ids().index(self._revision_id) + 1
         # This is identical now to the WorkingTree _generate_inventory except
         # for the tree index use.
         root_key, current_entry = self._dirstate._get_entry(parent_index, path_utf8='')
         current_id = root_key[2]
-        assert current_entry[parent_index][0] == 'd'
+        if current_entry[parent_index][0] != 'd':
+            raise AssertionError()
         inv = Inventory(root_id=current_id, revision_id=self._revision_id)
         inv.root.revision = current_entry[parent_index][4]
         # Turn some things into local variables
@@ -1525,8 +1533,12 @@
                     raise AssertionError("cannot convert entry %r into an InventoryEntry"
                             % entry)
                 # These checks cost us around 40ms on a 55k entry tree
-                assert file_id not in inv_byid
-                assert name_unicode not in parent_ie.children
+                if file_id in inv_byid:
+                    raise AssertionError('file_id %s already in'
+                        ' inventory as %s' % (file_id, inv_byid[file_id]))
+                if name_unicode in parent_ie.children:
+                    raise AssertionError('name %r already in parent'
+                        % (name_unicode,))
                 inv_byid[file_id] = inv_entry
                 parent_ie.children[name_unicode] = inv_entry
         self._inventory = inv
@@ -1796,19 +1808,21 @@
                 yield f
             return
         parent_ids = self.target.get_parent_ids()
-        assert (self.source._revision_id in parent_ids
-                or self.source._revision_id == NULL_REVISION), \
-                "revision {%s} is not stored in {%s}, but %s " \
-                "can only be used for trees stored in the dirstate" \
-                % (self.source._revision_id, self.target, self.iter_changes)
+        if not (self.source._revision_id in parent_ids
+                or self.source._revision_id == NULL_REVISION):
+            raise AssertionError(
+                "revision {%s} is not stored in {%s}, but %s "
+                "can only be used for trees stored in the dirstate"
+                % (self.source._revision_id, self.target, self.iter_changes))
         target_index = 0
         if self.source._revision_id == NULL_REVISION:
             source_index = None
             indices = (target_index,)
         else:
-            assert (self.source._revision_id in parent_ids), \
-                "Failure: source._revision_id: %s not in target.parent_ids(%s)" % (
-                self.source._revision_id, parent_ids)
+            if not (self.source._revision_id in parent_ids):
+                raise AssertionError(
+                    "Failure: source._revision_id: %s not in target.parent_ids(%s)" % (
+                    self.source._revision_id, parent_ids))
             source_index = 1 + parent_ids.index(self.source._revision_id)
             indices = (source_index, target_index)
         # -- make all specific_files utf8 --
@@ -1952,7 +1966,8 @@
             target_details = entry[1][target_index]
             target_minikind = target_details[0]
             if path_info is not None and target_minikind in 'fdlt':
-                assert target_index == 0
+                if not (target_index == 0):
+                    raise AssertionError()
                 link_or_sha1 = state.update_entry(entry, abspath=path_info[4],
                                                   stat_value=path_info[3])
                 # The entry may have been modified by update_entry
@@ -2071,9 +2086,10 @@
                         #       parent entry will be the same as the source entry.
                         target_parent_entry = state._get_entry(target_index,
                                                                path_utf8=new_dirname)
-                        assert target_parent_entry != (None, None), (
-                            "Could not find target parent in wt: %s\nparent of: %s"
-                            % (new_dirname, entry))
+                        if target_parent_entry == (None, None):
+                            raise AssertionError(
+                                "Could not find target parent in wt: %s\nparent of: %s"
+                                % (new_dirname, entry))
                         target_parent_id = target_parent_entry[0][2]
                     if target_parent_id == entry[0][2]:
                         # This is the root, so the parent is None
@@ -2262,7 +2278,8 @@
                     if current_dir_info[0][0] == '':
                         # remove .bzr from iteration
                         bzr_index = bisect_left(current_dir_info[1], ('.bzr',))
-                        assert current_dir_info[1][bzr_index][0] == '.bzr'
+                        if current_dir_info[1][bzr_index][0] != '.bzr':
+                            raise AssertionError()
                         del current_dir_info[1][bzr_index]
             # walk until both the directory listing and the versioned metadata
             # are exhausted. 

=== modified file 'bzrlib/xml4.py'
--- bzrlib/xml4.py	2007-10-05 02:41:37 +0000
+++ bzrlib/xml4.py	2008-04-24 07:22:53 +0000
@@ -50,7 +50,6 @@
         # for now, leaving them as null in the xml form.  in a future
         # version it will be implied by nested elements.
         if ie.parent_id != ROOT_ID:
-            assert isinstance(ie.parent_id, basestring)
             e.set('parent_id', ie.parent_id)
 
         e.tail = '\n'
@@ -63,7 +62,6 @@
 
         :param revision_id: Ignored parameter used by xml5.
         """
-        assert elt.tag == 'inventory'
         root_id = elt.get('file_id') or ROOT_ID
         inv = Inventory(root_id)
         for e in elt:
@@ -75,8 +73,6 @@
 
 
     def _unpack_entry(self, elt):
-        assert elt.tag == 'entry'
-
         ## original format inventories don't have a parent_id for
         ## nodes in the root directory, but it's cleaner to use one
         ## internally.
@@ -133,7 +129,6 @@
             for i, parent_id in enumerate(rev.parents):
                 p = SubElement(pelts, 'revision_ref')
                 p.tail = '\n'
-                assert parent_id
                 p.set('revision_id', parent_id)
                 if i < len(rev.parent_sha1s):
                     p.set('revision_sha1', rev.parent_sha1s[i])
@@ -161,14 +156,11 @@
 
         if pelts:
             for p in pelts:
-                assert p.tag == 'revision_ref', \
-                       "bad parent node tag %r" % p.tag
                 rev.parent_ids.append(p.get('revision_id'))
                 rev.parent_sha1s.append(p.get('revision_sha1'))
             if precursor:
                 # must be consistent
                 prec_parent = rev.parent_ids[0]
-                assert prec_parent == precursor
         elif precursor:
             # revisions written prior to 0.0.5 have a single precursor
             # give as an attribute

=== modified file 'bzrlib/xml5.py'
--- bzrlib/xml5.py	2008-03-28 03:09:47 +0000
+++ bzrlib/xml5.py	2008-04-24 07:22:53 +0000
@@ -32,7 +32,6 @@
     def _unpack_inventory(self, elt, revision_id):
         """Construct from XML Element
         """
-        assert elt.tag == 'inventory'
         root_id = elt.get('file_id') or inventory.ROOT_ID
         root_id = xml8._get_utf8_or_ascii(root_id)
 

=== modified file 'bzrlib/xml8.py'
--- bzrlib/xml8.py	2008-04-17 05:49:53 +0000
+++ bzrlib/xml8.py	2008-04-24 07:22:53 +0000
@@ -161,8 +161,10 @@
         :param inv: An inventory about to be serialised, to be checked.
         :raises: AssertionError if an error has occured.
         """
-        assert inv.revision_id is not None
-        assert inv.root.revision is not None
+        if inv.revision_id is None:
+            raise AssertionError()
+        if inv.root.revision is None:
+            raise AssertionError()
 
     def write_inventory_to_lines(self, inv):
         """Return a list of lines with the encoded inventory."""
@@ -316,7 +318,6 @@
             pelts = SubElement(root, 'parents')
             pelts.tail = pelts.text = '\n'
             for parent_id in rev.parent_ids:
-                assert isinstance(parent_id, basestring)
                 _mod_revision.check_not_reserved_id(parent_id)
                 p = SubElement(pelts, 'revision_ref')
                 p.tail = '\n'
@@ -330,8 +331,6 @@
     def _pack_revision_properties(self, rev, under_element):
         top_elt = SubElement(under_element, 'properties')
         for prop_name, prop_value in sorted(rev.properties.items()):
-            assert isinstance(prop_name, basestring) 
-            assert isinstance(prop_value, basestring) 
             prop_elt = SubElement(top_elt, 'property')
             prop_elt.set('name', prop_name)
             prop_elt.text = prop_value
@@ -353,7 +352,6 @@
         for e in elt:
             ie = self._unpack_entry(e)
             inv.add(ie)
-        assert inv.root.revision is not None
         return inv
 
     def _unpack_entry(self, elt):
@@ -397,7 +395,6 @@
 
     def _unpack_revision(self, elt):
         """XML Element -> Revision object"""
-        assert elt.tag == 'revision'
         format = elt.get('format')
         format_num = self.format_num
         if self.revision_format_num is not None:
@@ -414,8 +411,6 @@
                        )
         parents = elt.find('parents') or []
         for p in parents:
-            assert p.tag == 'revision_ref', \
-                   "bad parent node tag %r" % p.tag
             rev.parent_ids.append(get_cached(p.get('revision_id')))
         self._unpack_revision_properties(elt, rev)
         v = elt.get('timezone')
@@ -429,12 +424,12 @@
     def _unpack_revision_properties(self, elt, rev):
         """Unpack properties onto a revision."""
         props_elt = elt.find('properties')
-        assert len(rev.properties) == 0
         if not props_elt:
             return
         for prop_elt in props_elt:
-            assert prop_elt.tag == 'property', \
-                "bad tag under properties list: %r" % prop_elt.tag
+            if prop_elt.tag != 'property':
+                raise AssertionError(
+                    "bad tag under properties list: %r" % prop_elt.tag)
             name = prop_elt.get('name')
             value = prop_elt.text
             # If a property had an empty value ('') cElementTree reads
@@ -442,8 +437,8 @@
             # properties have string values
             if value is None:
                 value = ''
-            assert name not in rev.properties, \
-                "repeated property %r" % name
+            if name in rev.properties:
+                raise AssertionError("repeated property %r" % name)
             rev.properties[name] = value
 
 

